import os
from pathlib import Path
from typing import Dict, List

import datasets

from seacrowd.utils import schemas
from seacrowd.utils.configs import SEACrowdConfig
from seacrowd.utils.constants import Tasks

_CITATION = """\
@article{published_papers/22434604,
  title = {TUFS Asian Language Parallel Corpus (TALPCo)},
  author = {Hiroki Nomoto and Kenji Okano and David Moeljadi and Hideo Sawada},
  journal = {言語処理学会 第24回年次大会 発表論文集},
  pages = {436--439},
  year = {2018}
}
@article{published_papers/22434603,
  title = {Interpersonal meaning annotation for Asian language corpora: The case of TUFS Asian Language Parallel Corpus (TALPCo)},
  author = {Hiroki Nomoto and Kenji Okano and Sunisa Wittayapanyanon and Junta Nomura},
  journal = {言語処理学会 第25回年次大会 発表論文集},
  pages = {846--849},
  year = {2019}
}
"""
_DATASETNAME = "talpco"
_DESCRIPTION = """\
The TUFS Asian Language Parallel Corpus (TALPCo) is an open parallel corpus consisting of Japanese sentences
and their translations into Korean, Burmese (Myanmar; the official language of the Republic of the Union of Myanmar),
Malay (the national language of Malaysia, Singapore and Brunei), Indonesian, Thai, Vietnamese and English.
"""
_HOMEPAGE = "https://github.com/matbahasa/TALPCo"
_LOCAL = False
_LANGUAGES = ["eng", "ind", "jpn", "kor", "myn", "tha", "vie", "zsm"]
_LICENSE = "CC-BY 4.0"
_URLS = {
    _DATASETNAME: "https://github.com/matbahasa/TALPCo/archive/refs/heads/master.zip",
}
_SUPPORTED_TASKS = [Tasks.MACHINE_TRANSLATION]
_SOURCE_VERSION = "1.0.0"
_SEACROWD_VERSION = "1.0.0"


def seacrowd_config_constructor(lang_source, lang_target, schema, version):
    """Construct SEACrowdConfig with talpco_{lang_source}_{lang_target}_{schema} as the name format"""
    if schema != "source" and schema != "seacrowd_t2t":
        raise ValueError(f"Invalid schema: {schema}")

    if lang_source == "" and lang_target == "":
        return SEACrowdConfig(
            name="talpco_{schema}".format(schema=schema),
            version=datasets.Version(version),
            description="talpco with {schema} schema for all 7 language pairs from / to ind language".format(schema=schema),
            schema=schema,
            subset_id="talpco",
        )
    else:
        return SEACrowdConfig(
            name="talpco_{lang_source}_{lang_target}_{schema}".format(lang_source=lang_source, lang_target=lang_target, schema=schema),
            version=datasets.Version(version),
            description="talpco with {schema} schema for {lang_source} source language and  {lang_target} target language".format(lang_source=lang_source, lang_target=lang_target, schema=schema),
            schema=schema,
            subset_id="talpco",
        )


class TALPCo(datasets.GeneratorBasedBuilder):
    """TALPCo datasets contains 1372 datasets in 8 languages"""

    BUILDER_CONFIGS = (
        [seacrowd_config_constructor(lang1, lang2, "source", _SOURCE_VERSION) for lang1 in _LANGUAGES for lang2 in _LANGUAGES if lang1 != lang2]
        + [seacrowd_config_constructor(lang1, lang2, "seacrowd_t2t", _SEACROWD_VERSION) for lang1 in _LANGUAGES for lang2 in _LANGUAGES if lang1 != lang2]
        + [seacrowd_config_constructor("", "", "source", _SOURCE_VERSION), seacrowd_config_constructor("", "", "seacrowd_t2t", _SEACROWD_VERSION)]
    )

    DEFAULT_CONFIG_NAME = "talpco_jpn_ind_source"

    def _info(self) -> datasets.DatasetInfo:
        if self.config.schema == "source" or self.config.schema == "seacrowd_t2t":
            features = schemas.text2text_features
        else:
            raise ValueError(f"Invalid config schema: {self.config.schema}")

        return datasets.DatasetInfo(
            description=_DESCRIPTION,
            features=features,
            homepage=_HOMEPAGE,
            license=_LICENSE,
            citation=_CITATION,
        )

    def _split_generators(self, dl_manager: datasets.DownloadManager) -> List[datasets.SplitGenerator]:
        urls = _URLS[_DATASETNAME]
        base_path = Path(dl_manager.download_and_extract(urls)) / "TALPCo-master"
        data = {}
        for lang in _LANGUAGES:
            lang_file_name = "data_" + lang + ".txt"
            lang_file_path = base_path / lang / lang_file_name
            if os.path.isfile(lang_file_path):
                with open(lang_file_path, "r") as file:
                    data[lang] = file.read().strip("\n").split("\n")

        return [
            datasets.SplitGenerator(
                name=datasets.Split.TRAIN,
                gen_kwargs={
                    "data": data,
                    "split": "train",
                },
            ),
        ]

    def _generate_examples(self, data: Dict, split: str):
        if self.config.schema != "source" and self.config.schema != "seacrowd_t2t":
            raise ValueError(f"Invalid config schema: {self.config.schema}")

        if self.config.name == "talpco_source" or self.config.name == "talpco_seacrowd_t2t":
            # load all 7 language pairs from / to ind language
            lang_target = "ind"
            for lang_source in _LANGUAGES:
                if lang_source == lang_target:
                    continue
                for language_pair_data in self.generate_language_pair_data(lang_source, lang_target, data):
                    yield language_pair_data

            lang_source = "ind"
            for lang_target in _LANGUAGES:
                if lang_source == lang_target:
                    continue
                for language_pair_data in self.generate_language_pair_data(lang_source, lang_target, data):
                    yield language_pair_data
        else:
            _, lang_source, lang_target = self.config.name.replace(f"_{self.config.schema}", "").split("_")
            for language_pair_data in self.generate_language_pair_data(lang_source, lang_target, data):
                yield language_pair_data

    def generate_language_pair_data(self, lang_source, lang_target, data):
        dict_source = {}
        for row in data[lang_source]:
            id, text = row.split("\t")
            dict_source[id] = text

        dict_target = {}
        for row in data[lang_target]:
            id, text = row.split("\t")
            dict_target[id] = text

        all_ids = set([k for k in dict_source.keys()] + [k for k in dict_target.keys()])
        dict_merged = {k: [dict_source.get(k), dict_target.get(k)] for k in all_ids}

        for id in sorted(all_ids):
            ex = {
                "id": lang_source + "_"  + lang_target + "_"  + id,
                "text_1": dict_merged[id][0],
                "text_2": dict_merged[id][1],
                "text_1_name": lang_source,
                "text_2_name": lang_target,
            }
            yield lang_source + "_" + lang_target + "_"  + id, ex



from pathlib import Path
from typing import List

import datasets

from seacrowd.utils import schemas
from seacrowd.utils.configs import SEACrowdConfig
from seacrowd.utils.constants import Tasks, DEFAULT_SOURCE_VIEW_NAME, DEFAULT_SEACROWD_VIEW_NAME

_DATASETNAME = "indo_religious_mt_en_id"
_SOURCE_VIEW_NAME = DEFAULT_SOURCE_VIEW_NAME
_UNIFIED_VIEW_NAME = DEFAULT_SEACROWD_VIEW_NAME

_LANGUAGES = ["ind", "eng"]  # We follow ISO639-3 language code (https://iso639-3.sil.org/code_tables/639/data)
_LOCAL = False
_CITATION = """\
@inproceedings{guntara-etal-2020-benchmarking,
    title = "Benchmarking Multidomain {E}nglish-{I}ndonesian Machine Translation",
    author = "Guntara, Tri Wahyu  and
      Aji, Alham Fikri  and
      Prasojo, Radityo Eko",
    booktitle = "Proceedings of the 13th Workshop on Building and Using Comparable Corpora",
    month = may,
    year = "2020",
    address = "Marseille, France",
    publisher = "European Language Resources Association",
    url = "https://aclanthology.org/2020.bucc-1.6",
    pages = "35--43",
    abstract = "In the context of Machine Translation (MT) from-and-to English, Bahasa Indonesia has been considered a low-resource language, and therefore applying Neural Machine Translation (NMT) which typically requires large training dataset proves to be problematic. In this paper, we show otherwise by collecting large, publicly-available datasets from the Web, which we split into several domains: news, religion, general, and conversation, to train and benchmark some variants of transformer-based NMT models across the domains. We show using BLEU that our models perform well across them , outperform the baseline Statistical Machine Translation (SMT) models, and perform comparably with Google Translate. Our datasets (with the standard split for training, validation, and testing), code, and models are available on https://github.com/gunnxx/indonesian-mt-data.",
    language = "English",
    ISBN = "979-10-95546-42-9",
}
"""

_DESCRIPTION = """\
Indonesian Religious Domain MT En-Id consists of religious manuscripts or articles. These articles are different from news as they are not in a formal, informative style. Instead, they are written to advocate and inspire religious values, often times citing biblical or quranic anecdotes. An interesting property in the religion domain corpus is the localized names, for example, David to Daud, Mary to Maryam, Gabriel to Jibril, and more. In contrast, entity names are usually kept unchanged in other domains. We also find quite a handful of Indonesian translations of JW300 are missing the end sentence dot (.), even though the end sentence dot is present in their English counterpart. Some inconsistencies in the transliteration are also found, for example praying is sometimes written as \"salat\" or \"shalat\", or repentance as \"tobat\" or \"taubat\".
"""

_HOMEPAGE = "https://github.com/gunnxx/indonesian-mt-data/tree/master/religious"

_LICENSE = "Creative Commons Attribution Share-Alike 4.0 International"

_URLs = {
    "test.en": "https://raw.githubusercontent.com/gunnxx/indonesian-mt-data/master/religious/test.en",
    "test.id": "https://raw.githubusercontent.com/gunnxx/indonesian-mt-data/master/religious/test.id",
    "valid.en": "https://raw.githubusercontent.com/gunnxx/indonesian-mt-data/master/religious/valid.en",
    "valid.id": "https://raw.githubusercontent.com/gunnxx/indonesian-mt-data/master/religious/valid.id",
    "train.en.0": "https://raw.githubusercontent.com/gunnxx/indonesian-mt-data/master/religious/train.en.0",
    "train.en.1": "https://raw.githubusercontent.com/gunnxx/indonesian-mt-data/master/religious/train.en.1",
    "train.id.0": "https://raw.githubusercontent.com/gunnxx/indonesian-mt-data/master/religious/train.id.0",
    "train.id.1": "https://raw.githubusercontent.com/gunnxx/indonesian-mt-data/master/religious/train.id.1",
}

_SUPPORTED_TASKS = [Tasks.MACHINE_TRANSLATION]

_SOURCE_VERSION = "1.0.0"
_SEACROWD_VERSION = "1.0.0"


class IndoReligiousMTEnId(datasets.GeneratorBasedBuilder):
    """Indonesian Religious Domain MT En-Id is a machine translation dataset containing English-Indonesian parallel sentences collected from the religious manuscripts."""

    BUILDER_CONFIGS = [
        SEACrowdConfig(
            name="indo_religious_mt_en_id_source",
            version=datasets.Version(_SOURCE_VERSION),
            description="Bible En-Id source schema",
            schema="source",
            subset_id="indo_religious_mt_en_id",
        ),
        SEACrowdConfig(
            name="indo_religious_mt_en_id_seacrowd_t2t",
            version=datasets.Version(_SEACROWD_VERSION),
            description="Bible En-Id Nusantara schema",
            schema="seacrowd_t2t",
            subset_id="indo_religious_mt_en_id",
        ),
    ]

    DEFAULT_CONFIG_NAME = "indo_religious_mt_en_id_source"

    def _info(self):
        if self.config.schema == "source":
            features = datasets.Features(
                {
                    "text_1": datasets.Value("string"),
                    "text_2": datasets.Value("string"),
                }
            )
        elif self.config.schema == "seacrowd_t2t":
            features = schemas.text2text_features

        return datasets.DatasetInfo(
            description=_DESCRIPTION,
            features=features,
            homepage=_HOMEPAGE,
            license=_LICENSE,
            citation=_CITATION,
        )

    def _split_generators(self, dl_manager: datasets.DownloadManager) -> List[datasets.SplitGenerator]:
        data_files = {
            "test.en": Path(dl_manager.download_and_extract(_URLs["test.en"])),
            "test.id": Path(dl_manager.download_and_extract(_URLs["test.id"])),
            "valid.en": Path(dl_manager.download_and_extract(_URLs["valid.en"])),
            "valid.id": Path(dl_manager.download_and_extract(_URLs["valid.id"])),
            "train.en.0": Path(dl_manager.download_and_extract(_URLs["train.en.0"])),
            "train.en.1": Path(dl_manager.download_and_extract(_URLs["train.en.1"])),
            "train.id.0": Path(dl_manager.download_and_extract(_URLs["train.id.0"])),
            "train.id.1": Path(dl_manager.download_and_extract(_URLs["train.id.1"])),
        }

        return [
            datasets.SplitGenerator(
                name=datasets.Split.TEST,
                gen_kwargs={
                    "filepath": {
                        "en": [data_files["test.en"]],
                        "id": [data_files["test.id"]],
                    }
                },
            ),
            datasets.SplitGenerator(
                name=datasets.Split.VALIDATION,
                gen_kwargs={
                    "filepath": {
                        "en": [data_files["valid.en"]],
                        "id": [data_files["valid.id"]],
                    }
                },
            ),
            datasets.SplitGenerator(
                name=datasets.Split.TRAIN,
                gen_kwargs={
                    "filepath": {
                        "en": [data_files["train.en.0"], data_files["train.en.1"]],
                        "id": [data_files["train.id.0"], data_files["train.id.1"]],
                    }
                },
            ),
        ]

    def _generate_examples(self, filepath: dict):

        data_en = None
        for file in filepath["en"]:
            if data_en is None:
                data_en = open(file, "r").readlines()
            else:
                data_en += open(file, "r").readlines()

        data_id = None
        for file in filepath["id"]:
            if data_id is None:
                data_id = open(file, "r").readlines()
            else:
                data_id += open(file, "r").readlines()

        if self.config.schema == "source":
            for id, (row_en, row_id) in enumerate(zip(data_en, data_id)):
                ex = {
                    "text_1": row_en,
                    "text_2": row_id,
                }
                yield id, ex
        elif self.config.schema == "seacrowd_t2t":
            for id, (row_en, row_id) in enumerate(zip(data_en, data_id)):
                ex = {
                    "id": id,
                    "text_1": row_en,
                    "text_2": row_id,
                    "text_1_name": "eng",
                    "text_2_name": "ind",
                }
                yield id, ex
        else:
            raise ValueError(f"Invalid config: {self.config.name}")



# coding=utf-8
# Copyright 2022 The HuggingFace Datasets Authors and the current dataset script contributor.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
Filipino-Tagalog Product Reviews Sentiment Analysis
This is a machine learning dataset that can be used to analyze the sentiment of product reviews in Filipino-Tagalog.
The data is scraped from lazada Philippines.
"""
import os
from pathlib import Path
from typing import Dict, List, Tuple
import json

import datasets

from seacrowd.utils import schemas
from seacrowd.utils.configs import SEACrowdConfig
from seacrowd.utils.constants import Tasks, Licenses


_CITATION = """@misc{github,
  author={Eric Echemane},
  title={Filipino-Tagalog-Product-Reviews-Sentiment-Analysis},
  year={2022},
  url={https://github.com/EricEchemane/Filipino-Tagalog-Product-Reviews-Sentiment-Analysis/tree/main},
}
"""

_DATASETNAME = "lazada_review_filipino"


_DESCRIPTION = """Filipino-Tagalog Product Reviews Sentiment Analysis
This is a machine learning dataset that can be used to analyze the sentiment of product reviews in Filipino-Tagalog.
The dataset contains over 900+ weakly annotated Filipino reviews scraped from the Lazada Philippines platform. 
Each review is associated with a five star point rating where one is the lowest and five is the highest.
"""


_HOMEPAGE = "https://github.com/EricEchemane/Filipino-Tagalog-Product-Reviews-Sentiment-Analysis"

_LANGUAGES = ['fil', 'tgl']

_LICENSE = Licenses.UNKNOWN.value


_LOCAL = False



_URLS = {
    _DATASETNAME: "https://raw.githubusercontent.com/EricEchemane/Filipino-Tagalog-Product-Reviews-Sentiment-Analysis/main/data/reviews.json",
}


_SUPPORTED_TASKS = [Tasks.SENTIMENT_ANALYSIS]


_SOURCE_VERSION = "1.0.0"

_SEACROWD_VERSION = "1.0.0"



class LazadaReviewFilipinoDataset(datasets.GeneratorBasedBuilder):
    """The dataset contains over 900+ weakly annotated Filipino reviews scraped from the Lazada Philippines platform"""

    SOURCE_VERSION = datasets.Version(_SOURCE_VERSION)
    SEACROWD_VERSION = datasets.Version(_SEACROWD_VERSION)


    BUILDER_CONFIGS = [
        SEACrowdConfig(
            name="lazada_review_filipino_source",
            version=SOURCE_VERSION,
            description="lazada reviews in filipino source schema",
            schema="source",
            subset_id="lazada_review_filipino",
        ),
        SEACrowdConfig(
            name="lazada_review_filipino_seacrowd_text",
            version=SEACROWD_VERSION,
            description="lazada reviews in filipino SEACrowd schema",
            schema="seacrowd_text",
            subset_id="lazada_review_filipino",
        ),
    ]

    DEFAULT_CONFIG_NAME = "lazada_review_filipino_source"

    def _info(self) -> datasets.DatasetInfo:

        if self.config.schema == "source":
            features = datasets.Features({"index": datasets.Value("string"), "review": datasets.Value("string"),
                                          "rating": datasets.Value("string")})

        elif self.config.schema == "seacrowd_text":
            features = schemas.text_features(label_names=["1", "2", "3", "4", "5"])

        return datasets.DatasetInfo(
            description=_DESCRIPTION,
            features=features,
            homepage=_HOMEPAGE,
            license=_LICENSE,
            citation=_CITATION,
        )

    def _split_generators(self, dl_manager: datasets.DownloadManager) -> List[datasets.SplitGenerator]:
        """Returns SplitGenerators."""

        urls = _URLS[_DATASETNAME]
        data_dir = dl_manager.download_and_extract(urls)

        return [
            datasets.SplitGenerator(
                name=datasets.Split.TRAIN,

                gen_kwargs={
                    "filepath": data_dir,
                    "split": "train",
                },
            )
        ]

    def _generate_examples(self, filepath: Path, split: str) -> Tuple[int, Dict]:
        """Yields examples as (key, example) tuples."""
        with open(filepath, 'r') as file:
            data = json.load(file)

        if self.config.schema == "source":
            for i in range(len(data)):
                yield i, {"index": str(i), "review": data[i]['review'], "rating": data[i]['rating']}

        elif self.config.schema == "seacrowd_text":
            for i in range(len(data)):
                yield i, {"id": str(i), "text": data[i]['review'], "label": str(data[i]['rating'])}



# coding=utf-8
from pathlib import Path
from typing import Dict, List, Tuple

import datasets

from seacrowd.utils import schemas
from seacrowd.utils.configs import SEACrowdConfig
from seacrowd.utils.constants import Licenses, Tasks

_CITATION = """\
@article{Aung_Kyaw Thu_Hlaing_2023, place={Nonthaburi, Thailand}, title={mySentence: Sentence Segmentation for Myanmar Language
using Neural Machine Translation Approach}, volume={9}, url={https://ph05.tci-thaijo.org/index.php/JIIST/article/view/87},
number={October}, 
abstract="In the informal Myanmar language, for which most NLP applications are used, there is no predefined rule to mark the end of the sentence.
Therefore, in this paper, we contributed the first Myanmar sentence segmentation corpus and systemat
ically experimented with twelve neural sequence
labeling architectures trained and tested on both sentence and sentence+paragraph data. The word LSTM + Softmax achieved the highest accuracy of 99.95{\%}
while trained and tested on sentence-only data and 97.40{\%} while trained and tested on sentence + paragraph data.",
journal={Journal of Intelligent Informatics
and Smart Technology}, author={Aung, Thura and Kyaw Thu , Ye and Hlaing , Zar Zar}, year={2023}, month={Nov.}, pages={e001} };

@InProceedings{10.1007/978-3-031-36886-8_24,
author="Thu, Ye Kyaw
and Aung, Thura
and Supnithi, Thepchai",
editor="Nguyen, Ngoc Thanh
and Le-Minh, Hoa
and Huynh, Cong-Phap
and Nguyen, Quang-Vu",
title="Neural Sequence Labeling Based Sentence Segmentation for Myanmar Language",
booktitle="The 12th Conference on Information Technology and Its Applications",
year="2023",
publisher="Springer Nature Switzerland",
address="Cham",
pages="285--296",
abstract="In the informal Myanmar language, for which most NLP applications are used, there is no predefined rule to mark the end of the sentence.
Therefore, in this paper, we contributed the first Myanmar sentence segmentation corpus and systemat
ically experimented with twelve neural sequence
labeling architectures trained and tested on both sentence and sentence+paragraph data. The word LSTM + Softmax achieved the highest accuracy of 99.95{\%}
while trained and tested on sentence-only data and 97.40{\%} while trained and tested on sentence + paragraph data.",
isbn="978-3-031-36886-8"
}

"""

_DATASETNAME = "mysentence"
_DESCRIPTION = """\
mySentence is a corpus with a total size of around 55K for Myanmar sentence segmentation. In formal Burmese (Myanmar language), sentences are grammatically structured
and typically end with the "။" pote-ma symbol. However, informal language, more commonly used in daily conversations due to its natural flow, does not always follow predefined
rules for ending sentences, making it challenging for machines to identify sentence boundaries. In this corpus, each token of the sentences and paragraphs is tagged from start to finish.
"""

_HOMEPAGE = "https://github.com/ye-kyaw-thu/mySentence"
_LANGUAGES = ["mya"]
_LICENSE = Licenses.CC_BY_NC_SA_4_0.value
_LOCAL = False
_URLS = {
    "sent": {
        "train": "https://raw.githubusercontent.com/ye-kyaw-thu/mySentence/main/ver1.0/data/data-sent/sent_tagged/train.tagged",
        "valid": "https://raw.githubusercontent.com/ye-kyaw-thu/mySentence/main/ver1.0/data/data-sent/sent_tagged/valid.tagged",
        "test": "https://raw.githubusercontent.com/ye-kyaw-thu/mySentence/main/ver1.0/data/data-sent/sent_tagged/test.tagged",
    },
    "sent+para": {
        "train": "https://raw.githubusercontent.com/ye-kyaw-thu/mySentence/main/ver1.0/data/data-sent+para/sent+para_tagged/train.tagged",
        "valid": "https://raw.githubusercontent.com/ye-kyaw-thu/mySentence/main/ver1.0/data/data-sent+para/sent+para_tagged/valid.tagged",
        "test": "https://raw.githubusercontent.com/ye-kyaw-thu/mySentence/main/ver1.0/data/data-sent+para/sent+para_tagged/test.tagged",
    },
}

_SUPPORTED_TASKS = [Tasks.POS_TAGGING]
_SOURCE_VERSION = "1.0.0"
_SEACROWD_VERSION = "1.0.0"


class MysentenceDataset(datasets.GeneratorBasedBuilder):
    SOURCE_VERSION = datasets.Version(_SOURCE_VERSION)
    SEACROWD_VERSION = datasets.Version(_SEACROWD_VERSION)
    BUILDER_CONFIGS = [
        SEACrowdConfig(
            name=f"{_DATASETNAME}_source",
            version=SOURCE_VERSION,
            description=_DESCRIPTION,
            schema="source",
            subset_id=f"{_DATASETNAME}",
        ),
        SEACrowdConfig(
            name=f"{_DATASETNAME}_seacrowd_seq_label",
            version=SEACROWD_VERSION,
            description="sentences SEACrowd schema",
            schema="seacrowd_seq_label",
            subset_id=f"{_DATASETNAME}",
        ),
        SEACrowdConfig(
            name=f"{_DATASETNAME}_and_paragraphs_source",
            version=SOURCE_VERSION,
            description="sentences para source schema",
            schema="source",
            subset_id=f"{_DATASETNAME}_and_paragraphs",
        ),
        SEACrowdConfig(
            name=f"{_DATASETNAME}_and_paragraphs_seacrowd_seq_label",
            version=SEACROWD_VERSION,
            description="sentence para SEACrowd schema",
            schema="seacrowd_seq_label",
            subset_id=f"{_DATASETNAME}_and_paragraphs",
        ),
    ]

    DEFAULT_CONFIG_NAME = f"{_DATASETNAME}_source"

    def _info(self) -> datasets.DatasetInfo:
        if self.config.schema == "source":
            features = datasets.Features(
                {
                    "id": datasets.Value("string"),
                    "tokens": datasets.Sequence(datasets.Value("string")),
                    "labels": datasets.Sequence(datasets.Value("string")),
                }
            )
        else:
            features = schemas.seq_label_features(["B", "O", "N", "E"])
        return datasets.DatasetInfo(
            description=_DESCRIPTION,
            features=features,  # B (Begin), O (Other), N (Next), and E (End)
            homepage=_HOMEPAGE,
            license=_LICENSE,
            citation=_CITATION,
        )

    def _split_generators(self, dl_manager: datasets.DownloadManager) -> List[datasets.SplitGenerator]:
        """Returns SplitGenerators."""
        if self.config.subset_id == f"{_DATASETNAME}":
            DATA_URL_ = _URLS["sent"]
        elif self.config.subset_id == f"{_DATASETNAME}_and_paragraphs":
            DATA_URL_ = _URLS["sent+para"]
        else:
            raise ValueError(f"No related dataset id for {self.config.subset_id}")

        data_dir = dl_manager.download_and_extract(DATA_URL_)

        return [
            datasets.SplitGenerator(
                name=datasets.Split.TRAIN,
                gen_kwargs={"filepath": data_dir["train"]},
            ),
            datasets.SplitGenerator(
                name=datasets.Split.TEST,
                gen_kwargs={"filepath": data_dir["test"]},
            ),
            datasets.SplitGenerator(
                name=datasets.Split.VALIDATION,
                gen_kwargs={
                    "filepath": data_dir["valid"],
                },
            ),
        ]

    def _generate_examples(self, filepath: Path) -> Tuple[int, Dict]:

        with open(filepath, "r") as filein:
            examples = [line.strip("\n").split(" ") for line in filein.readlines()]
            for eid, exam in enumerate(examples):
                tokens = []
                pos = []
                for tok_chunk in exam:
                    tok_ = tok_chunk.split("/")
                    tokens.append(tok_[0])
                    pos.append(tok_[1])
                yield eid, {"id": str(eid), "tokens": tokens, "labels": pos}



# coding=utf-8
# Copyright 2024 The HuggingFace Datasets Authors and the current dataset script contributor.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
The Aya Dataset is a multilingual instruction fine-tuning dataset curated by an open-science community via Aya Annotation Platform from Cohere For AI. The dataset contains a total of 204k human-annotated prompt-completion pairs along with the demographics data of the annotators. This dataset can be used to train, finetune, and evaluate multilingual LLMs.
"""

from pathlib import Path
from typing import List

import datasets
import pandas as pd

from seacrowd.utils import schemas
from seacrowd.utils.configs import SEACrowdConfig
from seacrowd.utils.constants import Licenses, Tasks

_CITATION = """\
@misc{singh2024aya,
      title={Aya Dataset: An Open-Access Collection for Multilingual Instruction Tuning},
      author={Shivalika Singh and Freddie Vargus and Daniel Dsouza and Börje F. Karlsson and Abinaya Mahendiran and Wei-Yin Ko and Herumb Shandilya and Jay Patel and Deividas Mataciunas and Laura OMahony and Mike Zhang and Ramith Hettiarachchi and Joseph Wilson and Marina Machado and Luisa Souza Moura and Dominik Krzemiński and Hakimeh Fadaei and Irem Ergün and Ifeoma Okoh and Aisha Alaagib and Oshan Mudannayake and Zaid Alyafeai and Vu Minh Chien and Sebastian Ruder and Surya Guthikonda and Emad A. Alghamdi and Sebastian Gehrmann and Niklas Muennighoff and Max Bartolo and Julia Kreutzer and Ahmet Üstün and Marzieh Fadaee and Sara Hooker},
      year={2024},
      eprint={2402.06619},
      archivePrefix={arXiv},
      primaryClass={cs.CL}
}
"""

_DATASETNAME = "aya_dataset"

_DESCRIPTION = """\
The Aya Dataset is a multilingual instruction fine-tuning dataset curated by an open-science community via Aya Annotation Platform from Cohere For AI. The dataset contains a total of 204k human-annotated prompt-completion pairs along with the demographics data of the annotators. This dataset can be used to train, finetune, and evaluate multilingual LLMs.
"""

_HOMEPAGE = "https://huggingface.co/datasets/CohereForAI/aya_dataset"

_LANGUAGES = ["ceb", "ind", "jav", "mya", "tam", "tgl", "sun", "tha", "vie", "zsm"]

_LICENSE = Licenses.APACHE_2_0.value

_LOCAL = False

# This can be an arbitrarily nested dict/list of URLs (see below in `_split_generators` method)
_URLS = {
    "train": "https://huggingface.co/datasets/CohereForAI/aya_dataset/resolve/main/data/train-00000-of-00001.parquet",  # test split does not contain SEA languages
}

_SUPPORTED_TASKS = [Tasks.INSTRUCTION_TUNING]

_SOURCE_VERSION = "1.0.0"

_SEACROWD_VERSION = "1.0.0"

_SEACROWD_SCHEMA = "seacrowd_t2t"


def _aya_config_constructor(lang: str, schema: str, version: str) -> SEACrowdConfig:
    return SEACrowdConfig(
        name=f"{_DATASETNAME}_{lang}_{schema}",
        version=version,
        description=f"Aya Dataset {schema} schema",
        schema=schema,
        subset_id=f"Aya {lang}",
    )


class AyaDataset(datasets.GeneratorBasedBuilder):
    """
    The Aya Dataset is a multilingual instruction fine-tuning dataset curated by an open-science community via Aya Annotation Platform from Cohere For AI. The dataset contains a total of 204k human-annotated prompt-completion pairs along with the demographics data of the annotators. This dataset can be used to train, finetune, and evaluate multilingual LLMs.

    """

    SOURCE_VERSION = datasets.Version(_SOURCE_VERSION)
    SEACROWD_VERSION = datasets.Version(_SEACROWD_VERSION)

    def _populate_configs():
        configs = [_aya_config_constructor(lang, "source", _SOURCE_VERSION) for lang in _LANGUAGES] + [_aya_config_constructor(lang, _SEACROWD_SCHEMA, _SEACROWD_VERSION) for lang in _LANGUAGES]

        all_lang_source_config = SEACrowdConfig(
            name=f"{_DATASETNAME}_source",
            version=_SOURCE_VERSION,
            description="Aya Dataset source schema",
            schema="source",
            subset_id="Aya",
        )

        all_lang_t2t_config = SEACrowdConfig(
            name=f"{_DATASETNAME}_{_SEACROWD_SCHEMA}",
            version=_SEACROWD_VERSION,
            description=f"Aya Dataset {_SEACROWD_SCHEMA} schema",
            schema=_SEACROWD_SCHEMA,
            subset_id="Aya",
        )

        configs.append(all_lang_source_config)
        configs.append(all_lang_t2t_config)
        return configs

    BUILDER_CONFIGS = _populate_configs()

    DEFAULT_CONFIG_NAME = "aya_dataset_source"

    def _info(self) -> datasets.DatasetInfo:

        if self.config.schema == "source":
            features = datasets.Features(
                {
                    "inputs": datasets.Value("string"),
                    "targets": datasets.Value("string"),
                    "language": datasets.Value("string"),
                    "language_code": datasets.Value("string"),
                    "annotation_type": datasets.Value("string"),
                    "user_id": datasets.Value("string"),
                }
            )

        elif self.config.schema == "seacrowd_t2t":
            features = schemas.text2text_features

        return datasets.DatasetInfo(
            description=_DESCRIPTION,
            features=features,
            homepage=_HOMEPAGE,
            license=_LICENSE,
            citation=_CITATION,
        )

    def get_lang_filter(self, config_name: str):
        # aya_dataset_{lang}_{schema}
        tokens = config_name.split("_")
        if len(tokens) == 0 or len(tokens[2]) != 3:
            return None
        return tokens[2]

    def _split_generators(self, dl_manager: datasets.DownloadManager) -> List[datasets.SplitGenerator]:
        """Returns SplitGenerators."""

        url = _URLS["train"]
        data_dir = dl_manager.download_and_extract(url)

        return [
            datasets.SplitGenerator(
                name=datasets.Split.TRAIN,
                gen_kwargs={
                    "data_path": Path(data_dir),
                    "split": "train",
                },
            ),
        ]

    def _generate_examples(self, data_path: Path, split: str):
        """Yields examples as (key, example) tuples."""

        df = pd.read_parquet(data_path)

        lang_filter = self.get_lang_filter(self.config.name)
        if lang_filter is not None:
            df = df[df["language_code"] == lang_filter]
        else:
            df = df[df["language_code"].isin(_LANGUAGES)]

        if self.config.schema == "source":
            for idx, row in df.iterrows():
                data = row.to_dict()
                yield idx, data

        elif self.config.schema == "seacrowd_t2t":
            for idx, row in df.iterrows():
                sample = {
                    "id": str(idx),
                    "text_1": row["inputs"],
                    "text_2": row["targets"],
                    "text_1_name": "inputs",
                    "text_2_name": "targets",
                }
                yield idx, sample



# coding=utf-8
# Copyright 2022 The HuggingFace Datasets Authors and the current dataset script contributor.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import re
from pathlib import Path
from typing import Dict, List, Tuple

import datasets

from seacrowd.utils import schemas
from seacrowd.utils.configs import SEACrowdConfig
from seacrowd.utils.constants import Tasks

_CITATION = """\
@data{FK2/VTAHRH_2022,
    author = {ARDIYANTI SURYANI, ARIE and Widyantoro, Dwi Hendratmo and Purwarianti, Ayu and Sudaryat, Yayat},
    publisher = {Telkom University Dataverse},
    title = {{PoSTagged Sundanese Monolingual Corpus}},
    year = {2022},
    version = {DRAFT VERSION},
    doi = {10.34820/FK2/VTAHRH},
    url = {https://doi.org/10.34820/FK2/VTAHRH}
}

@INPROCEEDINGS{7437678,
  author={Suryani, Arie Ardiyanti and Widyantoro, Dwi Hendratmo and Purwarianti, Ayu and Sudaryat, Yayat},
  booktitle={2015 International Conference on Information Technology Systems and Innovation (ICITSI)},
  title={Experiment on a phrase-based statistical machine translation using PoS Tag information for Sundanese into Indonesian},
  year={2015},
  volume={},
  number={},
  pages={1-6},
  doi={10.1109/ICITSI.2015.7437678}
}
"""

_LANGUAGES = ["sun"]  # We follow ISO639-3 language code (https://iso639-3.sil.org/code_tables/639/data)
_LOCAL = False

_DATASETNAME = "postag_su"

_DESCRIPTION = """\
This dataset contains 3616 lines of Sundanese sentences taken from several online magazines (Mangle, Dewan Dakwah Jabar, and Balebat). \
Annotated with PoS Labels by several undergraduates of the Sundanese Language Education Study Program (PPBS), UPI Bandung.
"""

_HOMEPAGE = "https://dataverse.telkomuniversity.ac.id/dataset.xhtml?persistentId=doi:10.34820/FK2/VTAHRH"

_LICENSE = 'CC0 - "Public Domain Dedication"'

_URLS = {
    _DATASETNAME: "https://dataverse.telkomuniversity.ac.id/api/access/datafile/:persistentId?persistentId=doi:10.34820/FK2/VTAHRH/WQIFK8",
}

_SUPPORTED_TASKS = [Tasks.POS_TAGGING]

_SOURCE_VERSION = "1.1.0"

_SEACROWD_VERSION = "1.0.0"


class PosSunMonoDataset(datasets.GeneratorBasedBuilder):
    """PoSTagged Sundanese Monolingual Corpus"""

    SOURCE_VERSION = datasets.Version(_SOURCE_VERSION)
    SEACROWD_VERSION = datasets.Version(_SEACROWD_VERSION)

    # Based on Wicaksono, A. F., & Purwarianti, A. (2010). HMM Based Part-of-Speech Tagger for Bahasa Indonesia. On Proceedings of 4th International MALINDO (Malay and Indonesian Language) Workshop.
    POS_TAGS = [
        "",
        "!",
        '"',
        "'",
        ")",
        ",",
        "-",
        ".",
        "...",
        "....",
        "/",
        ":",
        ";",
        "?",
        "C",
        "CBI",
        "CC",
        "CDC",
        "CDI",
        "CDO",
        "CDP",
        "CDT",
        "CP",
        "CRB",
        "CS",
        "DC",
        "DT",
        "FE",
        "FW",
        "GM",
        "IN",
        "J",
        "JJ",
        "KA",
        "KK",
        "MD",
        "MG",
        "MN",
        "N",
        "NEG",
        "NN",
        "NNA",
        "NNG",
        "NNN",
        "NNO",
        "NNP",
        "NNPP",
        "NP",
        "NPP",
        "OP",
        "PB",
        "PCDP",
        "PR",
        "PRL",
        "PRL|IN",
        "PRN",
        "PRP",
        "RB",
        "RBT",
        "RB|RP",
        "RN",
        "RP",
        "SC",
        "SCC",
        "SC|IN",
        "SYM",
        "UH",
        "VB",
        "VBI",
        "VBT",
        "VRB",
        "W",
        "WH",
        "WHP",
        "WRP",
        "`",
        "–",
        "—",
        "‘",
        "’",
        "“",
        "”",
    ]

    BUILDER_CONFIGS = [
        SEACrowdConfig(
            name=f"{_DATASETNAME}_source",
            version=SOURCE_VERSION,
            description=f"{_DATASETNAME} source schema",
            schema="source",
            subset_id=f"{_DATASETNAME}",
        ),
        SEACrowdConfig(
            name=f"{_DATASETNAME}_seacrowd_seq_label",
            version=SEACROWD_VERSION,
            description=f"{_DATASETNAME} Nusantara Seq Label schema",
            schema="seacrowd_seq_label",
            subset_id=f"{_DATASETNAME}",
        ),
    ]

    DEFAULT_CONFIG_NAME = f"{_DATASETNAME}_source"

    def _info(self) -> datasets.DatasetInfo:

        if self.config.schema == "source":
            features = datasets.Features({"labeled_sentence": datasets.Value("string")})
        elif self.config.schema == "seacrowd_seq_label":
            features = schemas.seq_label_features(self.POS_TAGS)

        else:
            raise NotImplementedError(f"Schema '{self.config.schema}' is not defined.")

        return datasets.DatasetInfo(
            description=_DESCRIPTION,
            features=features,
            homepage=_HOMEPAGE,
            license=_LICENSE,
            citation=_CITATION,
        )

    def _split_generators(self, dl_manager: datasets.DownloadManager) -> List[datasets.SplitGenerator]:
        """Returns SplitGenerators."""
        urls = _URLS[_DATASETNAME]
        data_path = dl_manager.download(urls)

        return [
            datasets.SplitGenerator(
                name=datasets.Split.TRAIN,
                gen_kwargs={
                    "filepath": data_path,
                },
            ),
        ]

    def _generate_examples(self, filepath: Path) -> Tuple[int, Dict]:
        """Yields examples as (key, example) tuples."""

        def __hotfix(line):
            if line.endswith(" taun|NN 1953.|."):
                return line.replace(" taun|NN 1953.|.", " taun|NN 1953|CDP .|.")
            elif line.endswith(" jeung|CC|CC sasab|RB .|."):
                return line.replace(" jeung|CC|CC sasab|RB .|.", " jeung|CC sasab|RB .|.")
            elif line.startswith("Kagiatan|NN éta|DT dihadiran|VBT kira|-kira "):
                return line.replace("Kagiatan|NN éta|DT dihadiran|VBT kira|-kira ", "Kagiatan|NN éta|DT dihadiran|VBT kira-kira|DT ")
            return line

        with open(filepath, "r", encoding="utf8") as ipt:
            raw = list(map(lambda l: __hotfix(l.rstrip("\n ")), ipt))

        pat_0 = r"(,\|,|\?\|\?|-\|-|!\|!)"
        repl_spc = r" \1 "

        pat_1 = r"([A-Z”])(\.\|\.)"
        pat_2 = r"(\.\|\.)([^. ])"
        repl_spl = r"\1 \2"

        pat_3 = r"([^ ]+\|[^ ]+)\| "
        repl_del = r"\1 "

        pat_4 = r"\|\|"
        repl_dup = r"|"

        def __apply_regex(txt):
            for pat, repl in [(pat_0, repl_spc), (pat_1, repl_spl), (pat_2, repl_spl), (pat_3, repl_del), (pat_4, repl_dup)]:
                txt = re.sub(pat, repl, txt)
            return txt

        def __cleanse_label(token):
            text, label = token
            return text, re.sub(r"([A-Z]+)[.,)]", r"\1", label.upper())

        if self.config.schema == "source":
            for key, example in enumerate(raw):
                yield key, {"labeled_sentence": example}

        elif self.config.schema == "seacrowd_seq_label":
            spaced = list(map(__apply_regex, raw))
            data = list(map(lambda l: [__cleanse_label(tok.split("|", 1)) for tok in filter(None, l.split(" "))], spaced))

            for key, example in enumerate(data):
                tokens, labels = zip(*example)
                yield key, {"id": str(key), "tokens": tokens, "labels": labels}

        else:
            raise NotImplementedError(f"Schema '{self.config.schema}' is not defined.")


if __name__ == "__main__":
    datasets.load_dataset(__file__)



# coding=utf-8
# Copyright 2022 The HuggingFace Datasets Authors and the current dataset script contributor.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
Dataloader implementation for Old Javanese Wordnet dataset.
"""

from pathlib import Path
from typing import Dict, List, Tuple

import datasets
import pandas as pd

from seacrowd.utils.configs import SEACrowdConfig

_CITATION = """\
@inproceedings{moeljadi-aminullah-2020-building,
    title = "Building the Old {J}avanese {W}ordnet",
    author = "Moeljadi, David  and
      Aminullah, Zakariya Pamuji",
    booktitle = "Proceedings of the 12th Language Resources and Evaluation Conference",
    month = may,
    year = "2020",
    address = "Marseille, France",
    publisher = "European Language Resources Association",
    url = "https://aclanthology.org/2020.lrec-1.359",
    pages = "2940--2946",
    abstract = "This paper discusses the construction and the ongoing development of the Old Javanese Wordnet.
     The words were extracted from the digitized version of the Old Javanese{--}English Dictionary (Zoetmulder, 1982).
     The wordnet is built using the {`}expansion{'} approach (Vossen, 1998), leveraging on the Princeton Wordnet{'}s
     core synsets and semantic hierarchy, as well as scientific names. The main goal of our project was to produce a
     high quality, human-curated resource. As of December 2019, the Old Javanese Wordnet contains 2,054 concepts or
     synsets and 5,911 senses. It is released under a Creative Commons Attribution 4.0 International License
     (CC BY 4.0). We are still developing it and adding more synsets and senses. We believe that the lexical data
     made available by this wordnet will be useful for a variety of future uses such as the development of Modern
     Javanese Wordnet and many language processing tasks and linguistic research on Javanese.",
    language = "English",
    ISBN = "979-10-95546-34-4",
}
"""

_DATASETNAME = "ojw"

_DESCRIPTION = """\
This dataset contains Old Javanese written language aimed to build a machine readable sources for Old Javanese: providing a wordnet for the language (Moeljadi et. al., 2020).
"""


_HOMEPAGE = "https://github.com/davidmoeljadi/OJW"


_LICENSE = "Creative Commons Attribution 4.0 International (CC BY 4.0)"


_URLS = {
    _DATASETNAME: "https://raw.githubusercontent.com/davidmoeljadi/OJW/master/wn-kaw.tab",
}

_SUPPORTED_TASKS = []

_SOURCE_VERSION = "1.0.0"

_SEACROWD_VERSION = "1.0.0"

_LOCAL = False

_LANGUAGES = ["kaw"]


class OJW(datasets.GeneratorBasedBuilder):
    """Old Javanese Wordnet (OJW) is a dataset that contains Old Javanese words and each variants of the words if available.
    The dataset consists of 5038 rows and three columns: synset, tlemma, and tvariants."""

    SOURCE_VERSION = datasets.Version(_SOURCE_VERSION)
    SEACROWD_VERSION = datasets.Version(_SEACROWD_VERSION)

    BUILDER_CONFIGS = [
        SEACrowdConfig(
            name="ojw_source",
            version=SOURCE_VERSION,
            description="ojw source schema",
            schema="source",
            subset_id="ojw",
        ),
    ]

    DEFAULT_CONFIG_NAME = "ojw_source"

    def _info(self) -> datasets.DatasetInfo:
        if self.config.schema == "source":
            features = datasets.Features({"synset": datasets.Value("string"), "tlemma": datasets.Value("string"), "tvariants": datasets.Value("string")})

        return datasets.DatasetInfo(
            description=_DESCRIPTION,
            features=features,
            homepage=_HOMEPAGE,
            license=_LICENSE,
            citation=_CITATION,
        )

    def _split_generators(self, dl_manager: datasets.DownloadManager) -> List[datasets.SplitGenerator]:
        """Returns SplitGenerators."""

        urls = _URLS[_DATASETNAME]
        data_dir = dl_manager.download(urls)

        return [
            datasets.SplitGenerator(
                name=datasets.Split.TRAIN,
                gen_kwargs={
                    "filepath": data_dir,
                    "split": "train",
                },
            ),
        ]

    def _generate_examples(self, filepath: Path, split: str) -> Tuple[int, Dict]:
        """Yields examples as (key, example) tuples."""

        df = pd.read_csv(filepath, sep="\t", names=["synset", "tlemma", "tvariants"])

        if self.config.schema == "source":
            for key, example in df.iterrows():
                yield key, {
                    "synset": example["synset"],
                    "tlemma": example["tlemma"],
                    "tvariants": example["tvariants"],
                }



import os
from pathlib import Path
from typing import Dict, List, Tuple

import datasets
import pandas as pd

from seacrowd.utils import schemas
from seacrowd.utils.configs import SEACrowdConfig
from seacrowd.utils.constants import DEFAULT_SEACROWD_VIEW_NAME, DEFAULT_SOURCE_VIEW_NAME, Tasks

_DATASETNAME = "su_emot"
_SOURCE_VIEW_NAME = DEFAULT_SOURCE_VIEW_NAME
_UNIFIED_VIEW_NAME = DEFAULT_SEACROWD_VIEW_NAME

_LANGUAGES = ["sun"]
_LOCAL = False
_CITATION = """\
@INPROCEEDINGS{
9297929,  
author={Putra, Oddy Virgantara and Wasmanson, Fathin Muhammad and Harmini, Triana and Utama, Shoffin Nahwa},  
booktitle={2020 International Conference on Computer Engineering, Network, and Intelligent Multimedia (CENIM)},   
title={Sundanese Twitter Dataset for Emotion Classification},   
year={2020},  
volume={},  
number={},  
pages={391--395},  
doi={10.1109/CENIM51130.2020.9297929}
}
"""

_DESCRIPTION = """\
This is a dataset for emotion classification of Sundanese text. The dataset is gathered from Twitter API between January and March 2019 with 2518 tweets in total. 
The tweets filtered by using some hashtags which are represented Sundanese emotion, for instance, #persib, #corona, #saredih, #nyakakak, #garoblog, #sangsara, #gumujeng, #bungah, #sararieun, #ceurik, and #hariwang. 
This dataset contains four distinctive emotions: anger, joy, fear, and sadness. Each tweet is annotated using related emotion. For data
validation, the authors consulted a Sundanese language teacher for expert validation.
"""
_HOMEPAGE = "https://github.com/virgantara/sundanese-twitter-dataset"

_LICENSE = "UNKNOWN"

_URLS = {
	"datasets": "https://raw.githubusercontent.com/virgantara/sundanese-twitter-dataset/master/newdataset.csv"
}

_SUPPORTED_TASKS = [Tasks.EMOTION_CLASSIFICATION]


_SOURCE_VERSION = "1.0.0"

_SEACROWD_VERSION = "1.0.0"


class SuEmot(datasets.GeneratorBasedBuilder):
    """This is a dataset for emotion classification of Sundanese text. The dataset is gathered from Twitter API between January and March 2019 with 2518 tweets in total."""

    SOURCE_VERSION = datasets.Version(_SOURCE_VERSION)
    SEACROWD_VERSION = datasets.Version(_SEACROWD_VERSION)

    BUILDER_CONFIGS = [
        SEACrowdConfig(
            name="su_emot_source",
            version=SOURCE_VERSION,
            description="Sundanese Twitter Dataset for Emotion source schema",
            schema="source",
            subset_id="su_emot",
        ),
        SEACrowdConfig(
            name="su_emot_seacrowd_text",
            version=SEACROWD_VERSION,
            description="Sundanese Twitter Dataset for Emotion Nusantara schema",
            schema="seacrowd_text",
            subset_id="su_emot",
        ),
    ]

    DEFAULT_CONFIG_NAME = "su_emot_source"

    def _info(self) -> datasets.DatasetInfo:

        if self.config.schema == "source":
            features = datasets.Features({
                "index": datasets.Value("string"),
                "data": datasets.Value("string"), 
                "label": datasets.Value("string")})

        # For example seacrowd_kb, seacrowd_t2t
        elif self.config.schema == "seacrowd_text":
            features = schemas.text_features(["anger", "joy", "fear", "sadness"])

        return datasets.DatasetInfo(
            description=_DESCRIPTION,
            features=features,
            homepage=_HOMEPAGE,
            license=_LICENSE,
            citation=_CITATION,
        )

    def _split_generators(self, dl_manager: datasets.DownloadManager) -> List[datasets.SplitGenerator]:
        urls = _URLS
        data_dir = Path(dl_manager.download_and_extract(urls['datasets']))
        data_files = {"train":data_dir}

        return [
            datasets.SplitGenerator(
                name=datasets.Split.TRAIN,
                gen_kwargs={
                    "filepath": data_files['train'],
                    "split": "train",
                },
            )
        ]

    def _generate_examples(self, filepath: Path, split: str) -> Tuple[int, Dict]:

        df = pd.read_csv(filepath, sep=",", header="infer").reset_index()
        df.columns = ["index","label", "data"]

        if self.config.schema == "source":
            for row in df.itertuples():
                ex = {"index": str(row.index+1), "data": row.data, "label": row.label}
                yield row.index, ex
        elif self.config.schema == "seacrowd_text":
            for row in df.itertuples():
                ex = {"id": str(row.index+1), "text": row.data, "label": row.label}
                yield row.index, ex



# coding=utf-8
# Copyright 2020 The HuggingFace Datasets Authors and the current dataset script contributor.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""KoPI-NLLB corpus."""
import json

import datasets
import zstandard as zstd

from seacrowd.utils import schemas
from seacrowd.utils.configs import SEACrowdConfig
from seacrowd.utils.constants import (DEFAULT_SEACROWD_VIEW_NAME,
                                       DEFAULT_SOURCE_VIEW_NAME, Tasks)

logger = datasets.logging.get_logger(__name__)

_CITATION = """

Hefferman et al, Bitext Mining Using Distilled Sentence Representations for Low-Resource Languages. Arxiv https://arxiv.org/abs/2205.12654, 2022.
NLLB Team et al, No Language Left Behind: Scaling Human-Centered Machine Translation, Arxiv https://arxiv.org/abs/2207.04672, 2022.

"""
_DESCRIPTION = """\

KopI(Korpus Perayapan Indonesia)-NLLB, is Indonesian family language(aceh,bali,banjar,indonesia,jawa,minang,sunda) only extracted from NLLB Dataset, allenai/nllb

each language set also filtered using some some deduplicate technique such as exact hash(md5) dedup technique and minhash LSH neardup

"""
_TYPE = ["raw", "dedup", "neardup"]


_CONF_LANG = ["ace_Latn", "ban_Latn", "bjn_Latn", "ind_Latn", "jav_Latn", "min_Latn", "sun_Latn"]

_CONFIGS = []
for j in _CONF_LANG:
    for m in _TYPE:
        _CONFIGS.append(j + "-" + m)

_ALL_CONFIG = ["all-raw", "all-dedup", "all-neardup"] + _CONFIGS

_HOMEPAGE = "https://huggingface.co/datasets/munggok/KoPI-NLLB"

_LICENSE = "ODC_C"

_BASE_URL = "https://huggingface.co/datasets/munggok/KoPI-NLLB/resolve/main/{tipe}/{lang}.json.zst"

_DATASETNAME = "kopi_nllb"

_SUPPORTED_TASKS = [Tasks.SELF_SUPERVISED_PRETRAINING]

_LANGUAGES = ["ind", "jav", "ace", "ban", "bjn", "min", "sun"]

_SEACROWD_VERSION = "1.0.0"

_SOURCE_VERSION = "2022.09.13"

_LOCAL = False

_SOURCE_VIEW_NAME = DEFAULT_SOURCE_VIEW_NAME

_UNIFIED_VIEW_NAME = DEFAULT_SEACROWD_VIEW_NAME

_URL = "https://huggingface.co/datasets/allenai/nllb"


def seacrowd_config_constructor(lang, schema, version):
    """Construct SEACrowdConfig"""
    if schema != "source" and schema != "seacrowd_ssp":
        raise ValueError(f"Invalid schema: {schema}")

    if lang == "":
        raise ValueError(f"Snapshot is required. Choose one of these Snapshot: {_ALL_CONFIG}.")
    elif lang in _ALL_CONFIG:
        return SEACrowdConfig(
            name=f"{_DATASETNAME}_{lang}_{schema}",
            version=datasets.Version(version),
            description=f"KoPI-NLLB with {schema} schema for {lang}",
            schema=schema,
            subset_id="kopi_nllb",
        )
    else:
        raise ValueError(f"Invalid language: {lang}. Choose one of these snapshots: {_ALL_CONFIG}.")


class KoPINLLBConfig(datasets.BuilderConfig):
    """BuilderConfig for the Clean KoPI corpus."""

    def __init__(self, **kwargs):
        """BuilderConfig for Clean KoPI corpus.
        Args:
            **kwargs: keyword arguments forwarded to super.
        """
        super().__init__(**kwargs)


class KoPINLLB(datasets.GeneratorBasedBuilder):
    """KoPI NLLB corpus."""

    BUILDER_CONFIGS = [seacrowd_config_constructor(sn, "source", _SOURCE_VERSION) for sn in _ALL_CONFIG] + [seacrowd_config_constructor(sn, "seacrowd_ssp", _SEACROWD_VERSION) for sn in _ALL_CONFIG]

    def _info(self):

        if self.config.schema == "source":
            features = datasets.Features(
                {
                    "text": datasets.Value("string"),
                    "url": datasets.Value("string"),
                    "score": datasets.Value("float32"),
                    "source": datasets.Value("string"),
                }
            )
        elif self.config.schema == "seacrowd_ssp":
            features = schemas.self_supervised_pretraining.features
        return datasets.DatasetInfo(
            description=_DESCRIPTION,
            features=features,
            homepage=_HOMEPAGE,
            license=_LICENSE,
            citation=_CITATION,
        )

    def _split_generators(self, dl_manager):
        name = self.config.name.replace("_" + self.config.schema, "")
        name = name.replace(_DATASETNAME + "_", "")
        split_name = name.split("-")
        if split_name[0] == "all":
            train = [_BASE_URL.format(tipe=split_name[1], lang=m) for m in _CONF_LANG]
        else:
            train = [_BASE_URL.format(tipe=split_name[1], lang=split_name[0])]
        train_downloaded_files = dl_manager.download(train)
        return [datasets.SplitGenerator(name=datasets.Split.TRAIN, gen_kwargs={"filepaths": train_downloaded_files})]

    def _generate_examples(self, filepaths):
        """This function returns the examples in the raw (text) form by iterating on all the files."""
        id_ = 0
        for filepath in filepaths:
            logger.info(f"Generating examples from {filepath}")
            with zstd.open(open(filepath, "rb"), "rt", encoding="utf-8") as f:
                for line in f:
                    if line:
                        example = json.loads(line)
                        if self.config.schema == "seacrowd_ssp":
                            yield id_, {"id": str(id_), "text": example["text"]}
                            id_ += 1
                        else:
                            yield id_, {"text": example["text"], "url": example["url"], "source": example["source"], "score": float(example["score"])}
                            id_ += 1



# coding=utf-8
import json
import os
from pathlib import Path
from typing import Dict, List, Tuple

import datasets

from seacrowd.utils import schemas
from seacrowd.utils.configs import SEACrowdConfig
from seacrowd.utils.constants import Licenses, Tasks

_CITATION = """\
@article{Lowphansirikul2021,
    author={Lowphansirikul, Lalita
            and Polpanumas, Charin
            and Rutherford, Attapol T.
            and Nutanong, Sarana},
    title={A large English--Thai parallel corpus from the web and machine-generated text},
    journal={Language Resources and Evaluation},
    year={2021},
    month={Mar},
    day={30},
    issn={1574-0218},
    doi={10.1007/s10579-021-09536-6},
    url={https://doi.org/10.1007/s10579-021-09536-6}
"""

_DATASETNAME = "scb_mt_en_th"

_DESCRIPTION = """\
A Large English-Thai Parallel Corpus The primary objective of our work is to build a large-scale English-Thai dataset
for machine translation. We construct an English-Thai machine translation dataset with over 1 million segment pairs,
curated from various sources, namely news, Wikipedia articles, SMS messages, task-based dialogs, web-crawled data and
government documents. Methodology for gathering data, building parallel texts and removing noisy sentence pairs are
presented in a reproducible manner. We train machine translation models based on this dataset. Our models' performance
are comparable to that of Google Translation API (as of May 2020) for Thai-English and outperform Google when the Open
Parallel Corpus (OPUS) is included in the training data for both Thai-English and English-Thai translation. The dataset,
pre-trained models, and source code to reproduce our work are available for public use.

"""

_HOMEPAGE = "https://github.com/vistec-AI/thai2nmt"

_LICENSE = Licenses.CC_BY_SA_4_0.value

_LANGUAGES = ["tha", "eng"]
_LOCAL = False

_URLS = {
    _DATASETNAME: "https://archive.org/download/scb_mt_enth_2020/data.zip",
}

_SUPPORTED_TASKS = [Tasks.MACHINE_TRANSLATION]

_SOURCE_VERSION = "1.0.0"

_SEACROWD_VERSION = "1.0.0"

SEACROWD_TO_SOURCE_LANGCODE_DICT = {"eng": "en", "tha": "th"}


class ScbMtEnThDataset(datasets.GeneratorBasedBuilder):
    """
    A Large English-Thai Parallel Corpus The primary objective of our work is to build a large-scale English-Thai
    dataset for machine translation. We construct an English-Thai machine translation dataset with over 1 million
    segment pairs, curated from various sources, namely news, Wikipedia articles, SMS messages, task-based dialogs,
     web-crawled data and government documents.
     Methodology for gathering data, building parallel texts and removing noisy sentence pairs are presented in a
     reproducible manner. We train machine translation models based on this dataset. Our models' performance are
     comparable to that of Google Translation API (as of May 2020) for Thai-English and outperform Google when the Open
     Parallel Corpus (OPUS) is included in the training data for both Thai-English and English-Thai translation.
     The dataset,pre-trained models, and source code to reproduce our work are available for public use."""

    SOURCE_VERSION = datasets.Version(_SOURCE_VERSION)
    SEACROWD_VERSION = datasets.Version(_SEACROWD_VERSION)

    BUILDER_CONFIGS = [
        SEACrowdConfig(
            name=f"{_DATASETNAME}_tha_eng_source",
            version=SOURCE_VERSION,
            description=f"{_DATASETNAME} source schema: Thai to English",
            schema="source",
            subset_id=f"{_DATASETNAME}",
        ),
        SEACrowdConfig(
            name=f"{_DATASETNAME}_tha_eng_seacrowd_t2t",
            version=SEACROWD_VERSION,
            description=f"{_DATASETNAME} SEACrowd schema: Thai to English",
            schema="seacrowd_t2t",
            subset_id=f"{_DATASETNAME}",
        ),
        SEACrowdConfig(
            name=f"{_DATASETNAME}_eng_tha_source",
            version=SOURCE_VERSION,
            description=f"{_DATASETNAME} source schema: English to Thai",
            schema="source",
            subset_id=f"{_DATASETNAME}",
        ),
        SEACrowdConfig(
            name=f"{_DATASETNAME}_eng_tha_seacrowd_t2t",
            version=SEACROWD_VERSION,
            description=f"{_DATASETNAME} SEACrowd schema: English to Thai",
            schema="seacrowd_t2t",
            subset_id=f"{_DATASETNAME}",
        ),
    ]

    DEFAULT_CONFIG_NAME = f"{_DATASETNAME}_tha_eng_source"

    def _info(self) -> datasets.DatasetInfo:
        if self.config.schema == "source":
            language_pair = [SEACROWD_TO_SOURCE_LANGCODE_DICT[lang] for lang in self.config.name.split("_")[4:6]]
            features = datasets.Features(
                {
                    "translation": datasets.features.Translation(language_pair),
                    "subdataset": datasets.Value("string"),
                }
            )
        elif self.config.schema == "seacrowd_t2t":
            features = schemas.text2text_features

        return datasets.DatasetInfo(
            description=_DESCRIPTION,
            features=features,
            homepage=_HOMEPAGE,
            license=_LICENSE,
            citation=_CITATION,
        )

    def _split_generators(self, dl_manager: datasets.DownloadManager) -> List[datasets.SplitGenerator]:
        urls = _URLS[_DATASETNAME]
        data_path = dl_manager.download_and_extract(urls)
        data_dir = os.path.join(data_path, "data")

        return [
            datasets.SplitGenerator(name=datasets.Split.TRAIN, gen_kwargs={"filepath": os.path.join(data_dir, "train.jsonl")}),
            datasets.SplitGenerator(name=datasets.Split.VALIDATION, gen_kwargs={"filepath": os.path.join(data_dir, "valid.jsonl")}),
            datasets.SplitGenerator(name=datasets.Split.TEST, gen_kwargs={"filepath": os.path.join(data_dir, "test.jsonl")}),
        ]

    def _generate_examples(self, filepath: Path) -> Tuple[int, Dict]:
        with open(filepath, encoding="utf-8") as f:
            if self.config.schema == "source":
                language_pair = [SEACROWD_TO_SOURCE_LANGCODE_DICT[lang] for lang in self.config.name.split("_")[4:6]]
                source, target = language_pair
                for id_, row in enumerate(f):
                    data = json.loads(row)
                    yield id_, {
                        "translation": {source: data[source], target: data[target]},
                        "subdataset": data["subdataset"],
                    }

            elif self.config.schema == "seacrowd_t2t":
                source, target = self.config.name.split("_")[4:6]
                for id_, row in enumerate(f):
                    data = json.loads(row)
                    ex = {
                        "id": str(id_),
                        "text_1": data[SEACROWD_TO_SOURCE_LANGCODE_DICT[source]],
                        "text_2": data[SEACROWD_TO_SOURCE_LANGCODE_DICT[target]],
                        "text_1_name": source,
                        "text_2_name": target,
                    }
                    yield id_, ex



# coding=utf-8
# Copyright 2022 The HuggingFace Datasets Authors and the current dataset script contributor.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from pathlib import Path
from typing import Dict, List, Tuple

import datasets
import pandas as pd

from seacrowd.utils import schemas
from seacrowd.utils.configs import SEACrowdConfig
from seacrowd.utils.constants import Licenses, Tasks

_CITATION = """\
@article{SeaEval2023,
  title={SeaEval for Multilingual Foundation Models: From Cross-Lingual Alignment to Cultural Reasoning},
  author={Wang, Bin and Liu, Zhengyuan and Huang, Xin and Jiao, Fangkai and Ding, Yang and Aw, Ai Ti and Chen, Nancy F.},
  journal={arXiv preprint arXiv:2309.04766},
  year={2023},
  url={https://github.com/SeaEval/SeaEval}
}
"""

_DATASETNAME = "seaeval"

_DESCRIPTION = """\
SeaEval is a benchmark toolkit for evaluating multilingual LLMs. The benchmark contains 28 datasets,
covering 7 languages. It contains 2 datasets for cross-lingual consistency, each containing parallel
questions for the 7 represented languages. It alsoc ontains 4 datasets for cultural reasoning
(multiple choice Q&A) that are in English but focused on regions including Singapore and Philipines.

This dataloader provides examples for Indonesia, Vietnamese, Malay, and Filipino.
"""

_HOMEPAGE = "https://github.com/SeaEval/SeaEval"

_LANGUAGES = {"ind": "Indonesian", "vie": "Vietnamese", "zlm": "Malay", "fil": "Filipino"}

_LICENSE = Licenses.CC_BY_NC_4_0.value

_LOCAL = False

_URLS = {
    "cross_mmlu": "https://huggingface.co/datasets/SeaEval/SeaEval_datasets/raw/main/cross_mmlu.json",
    "cross_logiqa": "https://huggingface.co/datasets/SeaEval/SeaEval_datasets/raw/main/cross_logiqa.json",
    "sg_eval": "https://huggingface.co/datasets/SeaEval/SeaEval_datasets/raw/main/sg_eval.json",
    "ph_eval": "https://huggingface.co/datasets/SeaEval/SeaEval_datasets/raw/main/ph_eval.json",
}

_SUPPORTED_TASKS = [Tasks.COMMONSENSE_REASONING, Tasks.QUESTION_ANSWERING]

_SOURCE_VERSION = "1.0.0"

_SEACROWD_VERSION = "1.0.0"


class SeaEvalDataset(datasets.GeneratorBasedBuilder):
    """
    SeaEval is a benchmark for evaluating multilingual LLMs from https://github.com/SeaEval/SeaEval.
    """

    SOURCE_VERSION = datasets.Version(_SOURCE_VERSION)
    SEACROWD_VERSION = datasets.Version(_SEACROWD_VERSION)

    LANGUAGES_EXCHANGED = dict((v, k) for k, v in _LANGUAGES.items())
    SUBSETS_CROSS_MMLU = ["cross_mmlu_" + lang for lang in _LANGUAGES.keys()]
    SUBSETS_CROSS_LOGIQA = ["cross_logiqa_" + lang for lang in _LANGUAGES.keys()]
    SUBSETS = SUBSETS_CROSS_MMLU + SUBSETS_CROSS_LOGIQA + ["sg_eval_eng", "ph_eval_eng"]

    BUILDER_CONFIGS = [
        SEACrowdConfig(
            name=f"{_DATASETNAME}_{subset}_source",
            version=datasets.Version(_SOURCE_VERSION),
            description=f"{_DATASETNAME}_{subset} source schema",
            schema="source",
            subset_id=f"{_DATASETNAME}_{subset}",
        )
        for subset in SUBSETS
    ]

    BUILDER_CONFIGS += [
        SEACrowdConfig(
            name=f"{_DATASETNAME}_{subset}_seacrowd_qa",
            version=datasets.Version(_SOURCE_VERSION),
            description=f"{_DATASETNAME}_{subset} SEACrowd schema",
            schema="seacrowd_qa",
            subset_id=f"{_DATASETNAME}_{subset}",
        )
        for subset in SUBSETS
    ]

    def _info(self) -> datasets.DatasetInfo:
        if self.config.schema == "source" and self.config.subset_id not in ["cross_logiqa", "ph_eval"]:
            features = datasets.Features(
                {
                    "id": datasets.Value("string"),
                    "question": datasets.Value("string"),
                    "choices": datasets.Sequence(datasets.Value("string")),
                    "answer": datasets.Value("string"),
                }
            )
        elif self.config.schema == "source" and self.config.subset_id == "cross_logiqa":
            features = datasets.Features(
                {
                    "id": datasets.Value("string"),
                    "question": datasets.Value("string"),
                    "context": datasets.Value("string"),
                    "choices": datasets.Sequence(datasets.Value("string")),
                    "answer": datasets.Value("string"),
                }
            )
        elif self.config.schema == "source" and self.config.subset_id == "ph_eval":
            features = datasets.Features(
                {
                    "id": datasets.Value("string"),
                    "question": datasets.Value("string"),
                    "choices": datasets.Sequence(datasets.Value("string")),
                    "answer": datasets.Value("string"),
                    "category": datasets.Value("string"),
                }
            )
        elif self.config.schema == "seacrowd_qa":
            features = schemas.qa_features
        else:
            raise ValueError(f"Unexpected schema received! {self.config.schema}")

        return datasets.DatasetInfo(
            description=_DESCRIPTION,
            features=features,
            homepage=_HOMEPAGE,
            license=_LICENSE,
            citation=_CITATION,
        )

    def _split_generators(self, dl_manager: datasets.DownloadManager) -> List[datasets.SplitGenerator]:
        """
        Returns SplitGenerators.
        """

        data = {key: dl_manager.download_and_extract(value) for key, value in _URLS.items()}

        paths = {}
        file = self.config.subset_id.split("_")
        file = "_".join(file[1:3])
        paths[self.config.subset_id] = data[file]

        return [
            datasets.SplitGenerator(
                name=datasets.Split.TEST,
                gen_kwargs={
                    "paths": paths,
                    "split": "test",
                },
            ),
        ]

    def _generate_examples(self, paths: Path, split: str) -> Tuple[int, Dict]:
        """
        Yields examples as (key, example) tuples.
        """

        language = self.config.subset_id.split("_")[3]
        examples = None

        for key, path in paths.items():
            if "cross" in key:
                data = pd.read_json(path).rename(columns=self.LANGUAGES_EXCHANGED)
                data = pd.melt(data, id_vars=["id"], value_vars=_LANGUAGES.keys(), var_name="language")
                data_flattened = pd.json_normalize(data["value"])
                data_merged = pd.merge(data, data_flattened, left_index=True, right_index=True)
                data_filtered = data_merged[data_merged["language"] == language].drop(columns=["value", "language"])
                examples = data_filtered.to_records()
            elif "eval" in key:
                data = pd.read_json(path)
                examples = data.to_records()

        idx = 0
        if self.config.schema == "source" and self.config.subset_id not in ["cross_logiqa", "ph_eval"]:
            for row in examples:
                x = {
                    "id": row["id"],
                    "question": row["question"],
                    "choices": row["choices"],
                    "answer": row["answer"],
                }
                yield idx, x
                idx += 1
        elif self.config.schema == "source" and self.config.subset_id == "cross_logiqa":
            for row in examples:
                x = {
                    "id": row["id"],
                    "question": row["question"],
                    "context": row["context"] if "context" in row else None,
                    "choices": row["choices"],
                    "answer": row["answer"],
                }
                yield idx, x
                idx += 1
        elif self.config.schema == "source" and self.config.subset_id == "ph_eval":
            for row in examples:
                x = {
                    "id": row["id"],
                    "question": row["question"],
                    "choices": row["choices"],
                    "answer": row["answer"],
                    "category": row["category"] if "category" in row else None,
                }
                yield idx, x
                idx += 1
        elif self.config.schema == "seacrowd_qa":
            for row in examples:
                x = {
                    "id": idx,
                    "question_id": row["id"],
                    "document_id": row["id"],
                    "question": row["question"],
                    "type": "multiple_choice",
                    "choices": row["choices"],
                    "context": row["context"] if "context" in row else None,
                    "answer": [row["answer"]],
                    "meta": {},
                }
                yield idx, x
                idx += 1
        else:
            raise ValueError(f"Invalid schema: {self.config.schema}")



from pathlib import Path
from typing import Dict, List, Tuple

import datasets
import pandas as pd

from seacrowd.utils import schemas
from seacrowd.utils.configs import SEACrowdConfig
from seacrowd.utils.constants import Licenses, Tasks

_CITATION = """
@inproceedings{DBLP:conf/nips/LaurenconSWAMSW22,
  author={Hugo Laurençon and Lucile Saulnier and Thomas Wang and Christopher Akiki and Albert Villanova del Moral and
  Teven Le Scao and Leandro von Werra and Chenghao Mou and Eduardo González Ponferrada and Huu Nguyen and Jörg Frohberg
  and Mario Sasko and Quentin Lhoest and Angelina McMillan-Major and Gérard Dupont and Stella Biderman and Anna Rogers
  and Loubna Ben Allal and Francesco De Toni and Giada Pistilli and Olivier Nguyen and Somaieh Nikpoor and Maraim Masoud
  and Pierre Colombo and Javier de la Rosa and Paulo Villegas and Tristan Thrush and Shayne Longpre and Sebastian Nagel
  and Leon Weber and Manuel Muñoz and Jian Zhu and Daniel van Strien and Zaid Alyafeai and Khalid Almubarak and Minh
  Chien Vu and Itziar Gonzalez-Dios and Aitor Soroa and Kyle Lo and Manan Dey and Pedro Ortiz Suarez and Aaron Gokaslan
  and Shamik Bose and David Ifeoluwa Adelani and Long Phan and Hieu Tran and Ian Yu and Suhas Pai and Jenny Chim and
  Violette Lepercq and Suzana Ilic and Margaret Mitchell and Alexandra Sasha Luccioni and Yacine Jernite},
  title={The BigScience ROOTS Corpus: A 1.6TB Composite Multilingual Dataset},
  year={2022},
  cdate={1640995200000},
  url={http://papers.nips.cc/paper_files/paper/2022/hash/ce9e92e3de2372a4b93353eb7f3dc0bd-Abstract-Datasets_and_Benchmarks.html},
  booktitle={NeurIPS},
}
"""

_DATASETNAME = "roots_vi_ted"

_DESCRIPTION = """
ROOTS_vi_ted is a subset of Vietnamese in ted_talks_iwslt datasets. ted_talks_iwslt is a collection of the original Ted
talks and their translated version. The translations are available in more than 109+ languages, though the distribution
is not uniform. Before using this dataloader, please accept the acknowledgement at
https://huggingface.co/datasets/bigscience-data/roots_vi_ted_talks_iwslt and use huggingface-cli login for authentication.
"""

_HOMEPAGE = "https://huggingface.co/datasets/bigscience-data/roots_vi_ted_talks_iwslt"

_LANGUAGES = ["vie"]

_LICENSE = Licenses.CC_BY_NC_ND_4_0.value

_LOCAL = False

_URLS = {_DATASETNAME: {"train": "https://huggingface.co/datasets/bigscience-data/roots_vi_ted_talks_iwslt/resolve/main/data/train-00000-of-00001.parquet?download=true"}}

_SUPPORTED_TASKS = [Tasks.SELF_SUPERVISED_PRETRAINING]

_SOURCE_VERSION = "1.0.0"

_SEACROWD_VERSION = "1.0.0"


class RootsViTedDataset(datasets.GeneratorBasedBuilder):
    """RootsViTed is a subset of Vietnamese in ted_talks_iwslt datasets."""

    SOURCE_VERSION = datasets.Version(_SOURCE_VERSION)
    SEACROWD_VERSION = datasets.Version(_SEACROWD_VERSION)

    BUILDER_CONFIGS = [
        SEACrowdConfig(
            name="roots_vi_ted_source",
            version=SOURCE_VERSION,
            description="roots_vi_ted source schema",
            schema="source",
            subset_id="roots_vi_ted",
        ),
        SEACrowdConfig(
            name="roots_vi_ted_seacrowd_ssp",
            version=SEACROWD_VERSION,
            description="roots_vi_ted SEACrowd schema",
            schema="seacrowd_ssp",
            subset_id="roots_vi_ted",
        ),
    ]

    DEFAULT_CONFIG_NAME = "roots_vi_ted_source"

    def _info(self) -> datasets.DatasetInfo:
        if self.config.schema == "source":
            features = datasets.Features(
                {
                    "text": datasets.Value("string"),
                    "meta": datasets.Value("string"),
                }
            )

        elif self.config.schema == "seacrowd_ssp":
            features = schemas.self_supervised_pretraining.features

        return datasets.DatasetInfo(
            description=_DESCRIPTION,
            features=features,
            homepage=_HOMEPAGE,
            license=_LICENSE,
            citation=_CITATION,
        )

    def _split_generators(self, dl_manager: datasets.DownloadManager) -> List[datasets.SplitGenerator]:
        """Returns SplitGenerators."""
        urls = _URLS[_DATASETNAME]
        data_dir = dl_manager.download_and_extract(urls)

        return [
            datasets.SplitGenerator(
                name=datasets.Split.TRAIN,
                gen_kwargs={"filepath": data_dir, "split": "train"},
            ),
        ]

    def _generate_examples(self, filepath: Path, split: str) -> Tuple[int, Dict]:
        if self.config.schema == "source":
            df = pd.read_parquet(filepath[split])
            for i, row in df.iterrows():
                yield i, {
                    "text": row["text"],
                    "meta": row["meta"],
                }

        elif self.config.schema == "seacrowd_ssp":
            df = pd.read_parquet(filepath[split])
            for i, row in df.iterrows():
                yield i, {
                    "id": str(i),
                    "text": row["text"],
                }



# coding=utf-8
# Copyright 2022 The HuggingFace Datasets Authors and the current dataset script contributor.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from pathlib import Path
from typing import Dict, List, Tuple

import datasets
import pandas as pd

from seacrowd.utils import schemas
from seacrowd.utils.configs import SEACrowdConfig
from seacrowd.utils.constants import DEFAULT_SEACROWD_VIEW_NAME, DEFAULT_SOURCE_VIEW_NAME, Tasks

_CITATION = """\
@INPROCEEDINGS{
7065828,
author={Trisedya, Bayu Distiawan and Inastra, Dyah},
booktitle={2014 International Conference on Advanced Computer Science and Information System},
title={Creating Indonesian-Javanese parallel corpora using wikipedia articles},
year={2014},
volume={},
number={},
pages={239-245},
doi={10.1109/ICACSIS.2014.7065828}}
"""

_DATASETNAME = "id_wiki_parallel"
_SOURCE_VIEW_NAME = DEFAULT_SOURCE_VIEW_NAME
_UNIFIED_VIEW_NAME = DEFAULT_SEACROWD_VIEW_NAME

_LANGUAGES = ["ind", "jav", "min", "sun"]
_LOCAL = False

_DESCRIPTION = """\
This dataset is designed for machine translation task, specifically jav->ind, min->ind, sun->ind, and vice versa. The data are taken
from sentences in Wikipedia.

(from the publication abstract)
Parallel corpora are necessary for multilingual researches especially in information retrieval (IR) and natural language processing (NLP). However, such corpora are hard to find, specifically for low-resources languages like ethnic
languages. Parallel corpora of ethnic languages were usually collected manually. On the other hand, Wikipedia as a free online encyclopedia is supporting more and more languages each year, including ethnic languages in Indonesia. It has
become one of the largest multilingual sites in World Wide Web that provides free distributed articles. In this paper, we explore a few sentence alignment methods which have been used before for another domain. We want to check whether
Wikipedia can be used as one of the resources for collecting parallel corpora of Indonesian and Javanese, an ethnic language in Indonesia. We used two approaches of sentence alignment by treating Wikipedia as both parallel corpora and
comparable corpora. In parallel corpora case, we used sentence length based and word correspondence methods. Meanwhile,
we used the characteristics of hypertext links from Wikipedia in comparable corpora case. After the experiments, we can
see that Wikipedia is useful enough for our purpose because both approaches gave positive results.
"""

_HOMEPAGE = "https://github.com/dindainastra/indowikiparalelcorpora"

_LICENSE = "Unknown"

_URLS = {
    _DATASETNAME: {
        "jav": "https://raw.githubusercontent.com/dindainastra/indowikiparalelcorpora/main/manualsets/indojv-parallel.csv",
        "min": "https://raw.githubusercontent.com/dindainastra/indowikiparalelcorpora/main/manualsets/indomin-parallel.csv",
        "sun": "https://raw.githubusercontent.com/dindainastra/indowikiparalelcorpora/main/manualsets/indosun-parallel.csv",
    }
}

_SUPPORTED_TASKS = [Tasks.MACHINE_TRANSLATION]

_SOURCE_VERSION = "1.0.0"
_SEACROWD_VERSION = "1.0.0"


class IdWikiParallel(datasets.GeneratorBasedBuilder):
    """
    This dataset is designed for machine translation task, specifically jav->ind, min->ind, sun->ind, and vice versa. The data are
    taken from sentences in Wikipedia."""

    ETHNIC_LANGUAGES = [lang for lang in _LANGUAGES if lang != "ind"]
    BUILDER_CONFIGS = [
        SEACrowdConfig(
            name="{dataset_name}_{src}_ind_source".format(dataset_name=_DATASETNAME, src=src),
            version=datasets.Version(_SOURCE_VERSION),
            description="ID Wiki Parallel source schema for {src} to ind and ind to {src}".format(src=src),
            schema="source",
            subset_id="{dataset_name}_{src}_ind".format(dataset_name=_DATASETNAME, src=src),
        )
        for src in ETHNIC_LANGUAGES
    ] + [
        SEACrowdConfig(
            name="{dataset_name}_{src}_ind_seacrowd_t2t".format(dataset_name=_DATASETNAME, src=src),
            version=datasets.Version(_SEACROWD_VERSION),
            description="ID Wiki Parallel  Nusantara schema for {src} to ind and ind to {src}".format(src=src),
            schema="seacrowd_t2t",
            subset_id="{dataset_name}_{src}_ind".format(dataset_name=_DATASETNAME, src=src),
        )
        for src in ETHNIC_LANGUAGES
    ]

    DEFAULT_CONFIG_NAME = "id_wiki_parallel_jav_ind_source"

    def _info(self) -> datasets.DatasetInfo:
        if self.config.schema == "source":
            features = datasets.Features({"id": datasets.Value("string"), "text_1": datasets.Value("string"), "text_2": datasets.Value("string")})
        elif self.config.schema == "seacrowd_t2t":
            features = schemas.text2text_features

        return datasets.DatasetInfo(
            description=_DESCRIPTION,
            features=features,
            homepage=_HOMEPAGE,
            license=_LICENSE,
            citation=_CITATION,
        )

    def _split_generators(self, dl_manager: datasets.DownloadManager) -> List[datasets.SplitGenerator]:
        split_config_name = self.config.name.split("_")
        src = split_config_name[3]
        data_file = Path(dl_manager.download_and_extract(_URLS[_DATASETNAME][src]))

        return [
            datasets.SplitGenerator(
                name=datasets.Split.TRAIN,
                gen_kwargs={
                    "filepath": data_file,
                    "split": "train",
                },
            )
        ]

    def _generate_examples(self, filepath: Path, split: str) -> Tuple[int, Dict]:
        """Yields examples as (key, example) tuples."""
        split_config_name = self.config.name.split("_")
        src = split_config_name[3]
        df = pd.read_csv(filepath, encoding="utf8").reset_index()

        for id, row in df.iterrows():
            src_txt = row[1]
            tgt_txt = row[2]
            if self.config.schema == "source":
                yield id, {"id": str(id), "text_1": src_txt, "text_2": tgt_txt}
            elif self.config.schema == "seacrowd_t2t":
                yield id, {"id": str(id), "text_1": src_txt, "text_2": tgt_txt, "text_1_name": src, "text_2_name": "ind"}



# coding=utf-8
# Copyright 2022 The HuggingFace Datasets Authors and the current dataset script contributor.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
KoPI-CC_NEWS corpus

[seacrowd_schema_name] = ssp
"""

import json
from typing import List

import datasets
import zstandard as zstd

from seacrowd.utils import schemas
from seacrowd.utils.configs import SEACrowdConfig
from seacrowd.utils.constants import (DEFAULT_SEACROWD_VIEW_NAME,
                                       DEFAULT_SOURCE_VIEW_NAME, Tasks)

_DATASETNAME = "kopi_cc_news"
_LOCAL = False
_LANGUAGES = ["ind"]  # We follow ISO639-3 language code (https://iso639-3.sil.org/code_tables/639/data)
_SOURCE_VIEW_NAME = DEFAULT_SOURCE_VIEW_NAME
_UNIFIED_VIEW_NAME = DEFAULT_SEACROWD_VIEW_NAME
_SUPPORTED_TASKS = [Tasks.SELF_SUPERVISED_PRETRAINING]
_URL = "https://commoncrawl.org/"
_CITATION = """\

"""

_DESCRIPTION = """\
    KoPI(Korpus Perayapan Indonesia)-CC_News is Indonesian Only Extract from CC NEWS Common Crawl from 2016-2022(july) ,each snapshots get extracted using warcio,trafilatura and filter using fasttext
"""

_HOMEPAGE = "https://huggingface.co/datasets/munggok/KoPI-CC_News"

_LICENSE = "CC0"

_URLS = "https://huggingface.co/datasets/munggok/KoPI-CC_News/resolve/main/data/cc_news_{year}_id.jsonl.zst"

_YEAR = ["2016", "2017", "2018", "2019", "2020", "2021", "2022"]

_ALL_CONFIG = _YEAR + ["all"]

_SOURCE_VERSION = "2018.12.01"

_SEACROWD_VERSION = "1.0.0"


def seacrowd_config_constructor(year, schema, version):
    """Construct SEACrowdConfig"""
    if schema != "source" and schema != "seacrowd_ssp":
        raise ValueError(f"Invalid schema: {schema}")

    if year == "":
        raise ValueError(f"Snapshot is required. Choose one of these Snapshot: {_ALL_CONFIG}.")
    elif year in _ALL_CONFIG:
        return SEACrowdConfig(
            name=f"{_DATASETNAME}_{year}_{schema}",
            version=datasets.Version(version),
            description=f"KoPI-CC_News with {schema} schema for {year}",
            schema=schema,
            subset_id="kopi_cc_news",
        )
    else:
        raise ValueError(f"Invalid language: {year}. Choose one of these snapshots: {_ALL_CONFIG}.")


class KoPICCNEWS(datasets.GeneratorBasedBuilder):

    DEFAULT_CONFIG_NAME = "2016"

    BUILDER_CONFIGS = [seacrowd_config_constructor(sn, "source", _SOURCE_VERSION) for sn in _ALL_CONFIG] + [seacrowd_config_constructor(sn, "seacrowd_ssp", _SEACROWD_VERSION) for sn in _ALL_CONFIG]

    def _info(self):
        if self.config.schema == "source":
            features = datasets.Features(
                {
                    "text": datasets.Value("string"),
                    "timestamp": datasets.Value("string"),
                    "url": datasets.Value("string"),
                    "meta": datasets.Value("string"),
                }
            )
        elif self.config.schema == "seacrowd_ssp":
            features = schemas.self_supervised_pretraining.features

        return datasets.DatasetInfo(
            description=_DESCRIPTION,
            features=features,
            homepage=_HOMEPAGE,
            license=_LICENSE,
            citation=_CITATION,
        )

    def _split_generators(self, dl_manager) -> List[datasets.SplitGenerator]:
        """Returns SplitGenerators."""
        name = self.config.name.replace("_" + self.config.schema, "")
        name = name.replace(_DATASETNAME + "_", "")
        if name == "all":
            urls = [_URLS.format(year=m) for m in _YEAR]
        else:
            urls = [_URLS.format(year=name)]
        path = dl_manager.download(urls)

        return [
            datasets.SplitGenerator(
                name=datasets.Split.TRAIN,
                gen_kwargs={"filepaths": path, "split": "train"},
            ),
        ]

    def _generate_examples(self, filepaths, split):
        """This function returns the examples in the raw (text) form by iterating on all the files."""
        id_ = 0
        for filepath in filepaths:
            with zstd.open(open(filepath, "rb"), "rt", encoding="utf-8") as f:
                for line in f:
                    if line:
                        example = json.loads(line)
                        if self.config.schema == "seacrowd_ssp":
                            yield id_, {"id": str(id_), "text": example["text"]}
                            id_ += 1
                        else:
                            yield id_, {"text": example["text"], "url": example["url"], "timestamp": example["timestamp"], "meta": example["meta"]}
                            id_ += 1



from pathlib import Path
from typing import Dict, List, Tuple

import datasets

from seacrowd.utils import schemas
from seacrowd.utils.configs import SEACrowdConfig
from seacrowd.utils.constants import Licenses, Tasks

_CITATION = """\
@inproceedings{burchell-etal-2023-open,
    title = "An Open Dataset and Model for Language Identification",
    author = "Burchell, Laurie  and
      Birch, Alexandra  and
      Bogoychev, Nikolay  and
      Heafield, Kenneth",
    editor = "Rogers, Anna  and
      Boyd-Graber, Jordan  and
      Okazaki, Naoaki",
    booktitle = "Proceedings of the 61st Annual Meeting of the Association for Computational Linguistics (Volume 2: Short Papers)",
    month = jul,
    year = "2023",
    address = "Toronto, Canada",
    publisher = "Association for Computational Linguistics",
    url = "https://aclanthology.org/2023.acl-short.75",
    doi = "10.18653/v1/2023.acl-short.75",
    pages = "865--879",
    abstract = "Language identification (LID) is a fundamental step in many natural language processing pipelines. However, current LID 
    systems are far from perfect, particularly on lower-resource languages. We present a LID model which achieves a macro-average F1 
    score of 0.93 and a false positive rate of 0.033{\%} across 201 languages, outperforming previous work. We achieve this by training 
    on a curated dataset of monolingual data, which we audit manually to ensure reliability. We make both the model and the dataset 
    available to the research community. Finally, we carry out detailed analysis into our model{'}s performance, both in comparison to 
    existing open models and by language class.",
}
"""

_LOCAL = False
_LANGUAGES = ["ace", "ban", "bjn", "bug", "ceb", "ilo", "ind", "jav", "kac", "khm", "lao", "min", "lus", "mya", "pag", "shn", "sun", "tgl", "tha", "vie", "war", "zsm"]  
_DATASETNAME = "openlid"

_DESCRIPTION = """\
This is an open dataset for language identification covering 201 languages, which are curated and audited manually to 
ensure high confidence in its data and language labels. 22 languages are native to Southeast Asia speakers.
"""

_HOMEPAGE = "https://github.com/laurieburchell/open-lid-dataset"
_LICENSE = Licenses.GPL_3_0.value
_URLS = {
    _DATASETNAME: "https://data.statmt.org/lid/lid201-data.tsv.gz",
}
_SUPPORTED_TASKS = [Tasks.LANGUAGE_IDENTIFICATION]
_SOURCE_VERSION = "1.0.0"
_SEACROWD_VERSION = "1.0.0"

# 201 languages. Each element contains a code for the language, and script (e.g. wol_Latn = Wolof in Latin script)
_TAGS = ['kbp_Latn', 'zul_Latn', 'zho_Hans', 'uig_Arab', 'smo_Latn', 'hrv_Latn', 'tgk_Cyrl', 'guj_Gujr', 'azj_Latn', 'mai_Deva', 'bul_Cyrl', 'hne_Deva', 'wol_Latn', 'ind_Latn', 'lit_Latn', 'epo_Latn', 'prs_Arab', 'kmr_Latn', 'fao_Latn', 'swh_Latn', 'slk_Latn', 'srp_Cyrl', 'bod_Tibt', 'eus_Latn', 'tir_Ethi', 'tam_Taml', 'kas_Deva', 'glg_Latn', 'crh_Latn', 'kon_Latn', 'ayr_Latn', 'por_Latn', 'ben_Beng', 'zho_Hant', 'bug_Latn', 'umb_Latn', 'tzm_Tfng', 'kan_Knda', 'tgl_Latn', 'luo_Latn', 'lij_Latn', 'hun_Latn', 'kin_Latn', 'hat_Latn', 'sag_Latn', 'khm_Khmr', 'heb_Hebr', 'hye_Armn', 'fuv_Latn', 'cjk_Latn', 'ckb_Arab', 'srd_Latn', 'cat_Latn', 'dan_Latn', 'lao_Laoo', 'fra_Latn', 'kam_Latn', 'aeb_Arab', 'ydd_Hebr', 'afr_Latn', 'khk_Cyrl', 'lug_Latn', 'lin_Latn', 'nya_Latn', 'tsn_Latn', 'dzo_Tibt', 'min_Latn', 'war_Latn', 'rus_Cyrl', 'nob_Latn', 'tpi_Latn', 'mlt_Latn', 'mni_Beng', 'ilo_Latn', 'amh_Ethi', 'taq_Latn', 'acq_Arab', 'gaz_Latn', 'ltg_Latn', 'kac_Latn', 'ibo_Latn', 'gle_Latn', 'mya_Mymr', 'grn_Latn', 'kik_Latn', 'jav_Latn', 'awa_Deva', 'ars_Arab', 'swe_Latn', 'uzn_Latn', 'mos_Latn', 'lus_Latn', 'mal_Mlym', 'ita_Latn', 'dik_Latn', 'ewe_Latn', 'sat_Olck', 'pan_Guru', 'est_Latn', 'kab_Latn', 'bam_Latn', 'pag_Latn', 'isl_Latn', 'eng_Latn', 'fon_Latn', 'kas_Arab', 'asm_Beng', 'lim_Latn', 'bjn_Arab', 'taq_Tfng', 'deu_Latn', 'pbt_Arab', 'pap_Latn', 'quy_Latn', 'kea_Latn', 'npi_Deva', 'xho_Latn', 'shn_Mymr', 'nso_Latn', 'urd_Arab', 'bos_Latn', 'ron_Latn', 'fur_Latn', 'gla_Latn', 'nus_Latn', 'ltz_Latn', 'arz_Arab', 'bem_Latn', 'fin_Latn', 'kir_Cyrl', 'tha_Thai', 'mag_Deva', 'azb_Arab', 'tel_Telu', 'ell_Grek', 'sot_Latn', 'spa_Latn', 'vie_Latn', 'yor_Latn', 'ceb_Latn', 'vec_Latn', 'sin_Sinh', 'pol_Latn', 'als_Latn', 'lmo_Latn', 'scn_Latn', 'ces_Latn', 'fij_Latn', 'run_Latn', 'som_Latn', 'mkd_Cyrl', 'mar_Deva', 'ast_Latn', 'san_Deva', 'ary_Arab', 'twi_Latn', 'acm_Arab', 'nno_Latn', 'zsm_Latn', 'mri_Latn', 'kor_Hang', 'sna_Latn', 'pes_Arab', 'ace_Latn', 'bak_Cyrl', 'kat_Geor', 'tur_Latn', 'jpn_Jpan', 'arb_Arab', 'ukr_Cyrl', 'yue_Hant', 'kaz_Cyrl', 'hau_Latn', 'nld_Latn', 'oci_Latn', 'apc_Arab', 'tum_Latn', 'ace_Arab', 'dyu_Latn', 'knc_Latn', 'knc_Arab', 'kmb_Latn', 'bel_Cyrl', 'slv_Latn', 'lvs_Latn', 'bho_Deva', 'tuk_Latn', 'snd_Arab', 'sun_Latn', 'lua_Latn', 'ajp_Arab', 'hin_Deva', 'tso_Latn', 'tat_Cyrl', 'cym_Latn', 'ory_Orya', 'ban_Latn', 'szl_Latn', 'plt_Latn', 'bjn_Latn', 'ssw_Latn']


class OpenLID(datasets.GeneratorBasedBuilder):
    """This is an open dataset for language identification covering 201 languages. 22 languages are native to Southeast Asia speakers."""

    SOURCE_VERSION = datasets.Version(_SOURCE_VERSION)
    SEACROWD_VERSION = datasets.Version(_SEACROWD_VERSION)

    BUILDER_CONFIGS = [
        SEACrowdConfig(
            name="openlid_source",
            version=SOURCE_VERSION,
            description="OpenLID source schema",
            schema="source",
            subset_id="openlid",
        ),
        SEACrowdConfig(
            name="openlid_seacrowd_text",
            version=SEACROWD_VERSION,
            description="OpenLID Nusantara schema",
            schema="seacrowd_text",
            subset_id="openlid",
        ),
    ]

    DEFAULT_CONFIG_NAME = "openlid_source"

    def _info(self) -> datasets.DatasetInfo:
        if self.config.schema == "source":
            features = datasets.Features({"id": datasets.Value("string"), "text": datasets.Value("string"), "label": datasets.Value("string"), "source": datasets.Value("string")})
        elif self.config.schema == "seacrowd_text":
            features = schemas.text_features(_TAGS)

        return datasets.DatasetInfo(
            description=_DESCRIPTION,
            features=features,
            homepage=_HOMEPAGE,
            license=_LICENSE,
            citation=_CITATION,
        )

    def _split_generators(self, dl_manager: datasets.DownloadManager) -> List[datasets.SplitGenerator]:
        """Returns SplitGenerators."""
        # Dataset does not have predetermined split, putting all as TRAIN
        urls = _URLS[_DATASETNAME]
        filepath = Path(dl_manager.download_and_extract(urls))

        return [
            datasets.SplitGenerator(
                name=datasets.Split.TRAIN,
                gen_kwargs={
                    "filepath": filepath,
                },
            ),
        ]

    def _generate_examples(self, filepath: Path) -> Tuple[int, Dict]:
        """Yields examples as (key, example) tuples."""
        # Dataset does not have id, using row index as id
        with open(filepath) as f:
            lines = f.readlines()

        if self.config.schema == "source":
            for _id, line in enumerate(lines):
                line = line.split("\t")
                ex = {
                    "id": str(_id),
                    "text": line[0],
                    "label": line[1],
                    "source": line[2].strip(),
                }
                yield _id, ex

        elif self.config.schema == "seacrowd_text":
            for _id, line in enumerate(lines):
                line = line.split("\t")
                ex = {
                    "id": str(_id),
                    "text": line[0],
                    "label": line[1],
                }
                yield _id, ex
        else:
            raise ValueError(f"Invalid config: {self.config.name}")



import os
from pathlib import Path
from typing import Dict, List, Tuple
from seacrowd.utils.constants import Tasks
from seacrowd.utils import schemas

import datasets
import json

from seacrowd.utils.configs import SEACrowdConfig

_CITATION = """\
@inproceedings{mahendra-etal-2018-cross,
    title = "Cross-Lingual and Supervised Learning Approach for {I}ndonesian Word Sense Disambiguation Task",
    author = "Mahendra, Rahmad  and
      Septiantri, Heninggar  and
      Wibowo, Haryo Akbarianto  and
      Manurung, Ruli  and
      Adriani, Mirna",
    booktitle = "Proceedings of the 9th Global Wordnet Conference",
    month = jan,
    year = "2018",
    address = "Nanyang Technological University (NTU), Singapore",
    publisher = "Global Wordnet Association",
    url = "https://aclanthology.org/2018.gwc-1.28",
    pages = "245--250",
    abstract = "Ambiguity is a problem we frequently face in Natural Language Processing. Word Sense Disambiguation (WSD) is a task to determine the correct sense of an ambiguous word. However, research in WSD for Indonesian is still rare to find. The availability of English-Indonesian parallel corpora and WordNet for both languages can be used as training data for WSD by applying Cross-Lingual WSD method. This training data is used as an input to build a model using supervised machine learning algorithms. Our research also examines the use of Word Embedding features to build the WSD model.",
}
"""

_LANGUAGES = ["ind"]  # We follow ISO639-3 language code (https://iso639-3.sil.org/code_tables/639/data)
_LOCAL = False

_DATASETNAME = "id_wsd"

_DESCRIPTION = """\
Word Sense Disambiguation (WSD) is a task to determine the correct sense of an ambiguous word.
The training data was collected from news websites and manually annotated. The words in training data were processed using the morphological analysis to obtain lemma.
The features being used were some words around the target word (including the words before and after the target word), the nearest verb from the
target word, the transitive verb around the target word, and the document context. 
"""

_HOMEPAGE = "https://github.com/rmahendra/Indonesian-WSD"

_LICENSE = "Unknown"

_URLS = {
    _DATASETNAME: "https://github.com/rmahendra/Indonesian-WSD/raw/master/dataset-clwsd-ina.zip",
}

_SUPPORTED_TASKS = [Tasks.WORD_SENSE_DISAMBIGUATION]

_SOURCE_VERSION = "1.0.0"

_SEACROWD_VERSION = "1.0.0"

_LABELS = [
    {
        "name": "atas",
        "file_ext": ""
    },
    {
        "name": "perdana",
        "file_ext": ".tab"
    },
    {
        "name": "alam",
        "file_ext": ".tab"
    },
    {
        "name": "dasar",
        "file_ext": ".tab"
    },
    {
        "name": "anggur",
        "file_ext": ".tab"
    },
    {
        "name": "kayu",
        "file_ext": ""
    }
]

class IndonesianWSD(datasets.GeneratorBasedBuilder):

    SOURCE_VERSION = datasets.Version(_SOURCE_VERSION)
    SEACROWD_VERSION = datasets.Version(_SEACROWD_VERSION)

    BUILDER_CONFIGS = [
        SEACrowdConfig(
            name="id_wsd_source",
            version=SOURCE_VERSION,
            description="Indonesian WSD source schema",
            schema="source",
            subset_id="id_wsd",
        ),
        SEACrowdConfig(
            name="id_wsd_seacrowd_t2t",
            version=SEACROWD_VERSION,
            description="Indonesian WSD Nusantara schema",
            schema="seacrowd_t2t",
            subset_id="id_wsd",
        ),
    ]

    DEFAULT_CONFIG_NAME = "indonesian_wsd_source"

    def _info(self) -> datasets.DatasetInfo:

        if self.config.schema == "source":
            features = datasets.Features(
                {
                    "text": datasets.Value("string"),
                    "label": datasets.Value("string"),
                }
            )

        elif self.config.schema == "seacrowd_t2t":
            features = schemas.text2text_features

        return datasets.DatasetInfo(
            description=_DESCRIPTION,
            features=features,
            homepage=_HOMEPAGE,
            license=_LICENSE,
            citation=_CITATION,
        )

    def _split_generators(self, dl_manager: datasets.DownloadManager) -> List[datasets.SplitGenerator]:
        urls = _URLS[_DATASETNAME]
        data_dir = dl_manager.download_and_extract(urls)

        data_dir = os.path.join(data_dir, "dataset")

        datas = []

        for label in _LABELS:
            file_name = f"{label['name']}_t01"
            if label["file_ext"] != "":
                file_name = f"{file_name}{label['file_ext']}"
            
            parsed_data = self._parse_file(os.path.join(data_dir, file_name))
            datas = datas + parsed_data

        path_dumped_file = os.path.join(data_dir, "data.json")
        
        with open(path_dumped_file, 'w') as f:
            f.write(json.dumps(datas))

        return [
            datasets.SplitGenerator(
                name=datasets.Split.TRAIN,
                gen_kwargs={
                    "filepath": path_dumped_file,
                    "split": "train",
                },
            ),
        ]

    def _generate_examples(self, filepath: Path, split: str) -> Tuple[int, Dict]:
        data = json.load(open(filepath, "r"))

        if self.config.schema == "source":
            key = 0
            for each_data in data:
                example = {
                    "label": each_data["sense_id"],
                    "text": each_data["text"]
                }
                yield key, example
                key+=1

        elif self.config.schema == "seacrowd_t2t":
            key = 0
            for each_data in data:
                example = {
                    "id": str(key+1),
                    "text_1": each_data["sense_id"],
                    "text_1_name": "label",
                    "text_2": each_data["text"],
                    "text_2_name": "text"
                }
                yield key, example
                key+=1

    def _parse_file(self, file_path):
        parsed_lines = open(file_path, "r").readlines()
        data = []
        for line in parsed_lines:
            if len(line.strip()) > 0:
                _, sense_id, text = line[:-1].split("\t")    
                data.append({
                    "sense_id": sense_id,
                    "text": text
                })
        return data
                




"""\
Tree Schema

This schema assumes a document with subnodes elements
and a tree hierarchy.

For example:

                    SUBNODE1 - word1
                  //
            NODE1 - SUBNODE2 - word2
        //
ROOT    -   NODE2 - SUBNODE3 - word3
        \\
            NODE3 - SUBNODE4 - word4
                  \\
                    SUBNODE5 - word5

Schema structure:

        "id": sentence_id,
        "passage": {
            "id": sentence_id,
            "type": None,
            "text": "word1 word2 word3 word4 word5"
            "offsets": [0, 29]
        },
        "nodes": [
            {
                "id": 0,
                "type": ROOT,
                "text": "word1 word2 word3 word4 word5",
                "offsets": [0, 29],
                "subnodes": [1, 2, 3]
            },
            {
                "id": 1,
                "type": NODE1,
                "text": "word1 word2",
                "offsets": [0, 11],
                "subnodes": [4, 5]
            },
            {
                "id": 2,
                "type": NODE2,
                "text": "word3",
                "offsets": [12, 17],
                "subnodes": [6]
            },
            {
                "id": 3,
                "type": NODE3,
                "text": "word4 word5",
                "offsets": [18, 29],
                "subnodes": [7, 8]
            },
            {
                "id": 4,
                "type": SUBNODE1,
                "text": "word1",
                "offsets": [0, 5],
                "subnodes": []
            },
            {
                "id": 5,
                "type": SUBNODE2,
                "text": "word2",
                "offsets": [6, 11],
                "subnodes": []
            },
            {
                "id": 6,
                "type": SUBNODE3,
                "text": "word3",
                "offsets": [12, 17],
                "subnodes": []
            },
            {
                "id": 7,
                "type": SUBNODE4,
                "text": "word4",
                "offsets": [18, 23],
                "subnodes": []
            },
            {
                "id": 8,
                "type": SUBNODE5,
                "text": "word5",
                "offsets": [24, 29],
                "subnodes": []
            }
        ]
"""
import datasets

features = datasets.Features(
    {
        "id": datasets.Value("string"),
        "passage": {
            "id": datasets.Value("string"),
            "type": datasets.Value("string"),
            "text": datasets.Sequence(datasets.Value("string")),
            "offsets": datasets.Sequence(datasets.Value("int32")),
        },
        "nodes": [
            {
                "id": datasets.Value("string"),
                "type": datasets.Value("string"),
                "text": datasets.Value("string"),
                "offsets": datasets.Sequence(datasets.Value("int32")),
                "subnodes": datasets.Sequence(datasets.Value("string")),  # ids of subnodes
            }
        ],
    }
)



import json
from pathlib import Path
from typing import List

import datasets

from seacrowd.utils import schemas
from seacrowd.utils.configs import SEACrowdConfig
from seacrowd.utils.constants import (DEFAULT_SEACROWD_VIEW_NAME,
                                       DEFAULT_SOURCE_VIEW_NAME, Tasks)

_DATASETNAME = "squad_id"
_SOURCE_VIEW_NAME = DEFAULT_SOURCE_VIEW_NAME
_UNIFIED_VIEW_NAME = DEFAULT_SEACROWD_VIEW_NAME

_LANGUAGES = ["ind"]  # We follow ISO639-3 language code (https://iso639-3.sil.org/code_tables/639/data)
_LOCAL = False
_CITATION = """\
@inproceedings{muis2020sequence,
  title={Sequence-to-sequence learning for indonesian automatic question generator},
  author={Muis, Ferdiant Joshua and Purwarianti, Ayu},
  booktitle={2020 7th International Conference on Advance Informatics: Concepts, Theory and Applications (ICAICTA)},
  pages={1--6},
  year={2020},
  organization={IEEE}
}
"""

_DESCRIPTION = """\
    This dataset contains Indonesian SQuAD v2.0 dataset (Google-translated).
    The dataset can be used for automatic question generation (AQG),
    or machine reading comphrehension(MRC) task.
"""

_HOMEPAGE = "https://github.com/FerdiantJoshua/question-generator"

_LICENSE = "TBD"

_URLs = {"train": "https://drive.google.com/uc?id=1LP0iB0Xe6nkbnSxMeclxexUfqCE9e5qH&export=download", "val": "https://drive.google.com/uc?id=1KZE92j3Cnf7N6o0qrVplBqXV2XlGxnvo&export=download"}

_SUPPORTED_TASKS = [Tasks.QUESTION_ANSWERING]

_SOURCE_VERSION = "1.0.0"
_SEACROWD_VERSION = "1.0.0"


class SQuADIdDataset(datasets.GeneratorBasedBuilder):
    """SQuADID dataset contains the Indonisian SQuAD 2.0 data (translated by google)."""

    BUILDER_CONFIGS = [
        SEACrowdConfig(
            name="squad_id_source",
            version=datasets.Version(_SOURCE_VERSION),
            description="SQUAD_ID source schema",
            schema="source",
            subset_id="squad_id",
        ),
        SEACrowdConfig(
            name="squad_id_seacrowd_qa",
            version=datasets.Version(_SEACROWD_VERSION),
            description="SQUAD_ID Nusantara schema",
            schema="seacrowd_qa",
            subset_id="squad_id",
        ),
    ]

    DEFAULT_CONFIG_NAME = "squad_id_source"

    def _info(self):
        if self.config.schema == "source":
            features = datasets.Features({"id": datasets.Value("string"), "context": datasets.Value("string"), "question": datasets.Value("string"), "answer": datasets.Sequence(datasets.Value("string"))})
        elif self.config.schema == "seacrowd_qa":
            features = schemas.qa_features

        return datasets.DatasetInfo(
            description=_DESCRIPTION,
            features=features,
            homepage=_HOMEPAGE,
            license=_LICENSE,
            citation=_CITATION,
        )

    def _split_generators(self, dl_manager: datasets.DownloadManager) -> List[datasets.SplitGenerator]:
        train_path = Path(dl_manager.download_and_extract(_URLs["train"]))
        val_path = Path(dl_manager.download_and_extract(_URLs["val"]))

        return [
            datasets.SplitGenerator(
                name=datasets.Split.TRAIN,
                gen_kwargs={"filepath": train_path},
            ),
            datasets.SplitGenerator(
                name=datasets.Split.VALIDATION,
                gen_kwargs={"filepath": val_path},
            ),
        ]

    def _generate_examples(self, filepath: Path):

        count = 0
        if self.config.schema == "seacrowd_qa" or self.config.schema == "source":
            with open(filepath, "r") as f:
                data = json.load(f)
                paragraphs = data["paragraphs"]
                for k, v in paragraphs.items():
                    for each_data in v:
                        qas_list = each_data["qas"]
                        for each_qa in qas_list:
                            if "indonesian_plausible_answers" in each_qa.keys():
                                answers = each_qa["indonesian_plausible_answers"]
                            elif "indonesian_answers" in each_qa.keys():
                                answers = each_qa["indonesian_answers"]
                            if self.config.schema == "seacrowd_qa":
                                yield count, {
                                    "id": each_qa["id"],
                                    "question_id": each_qa["id"],
                                    "document_id": k,
                                    "question": each_qa["question"],
                                    "type": "extractive",
                                    "choices": [],
                                    "context": each_data["context"],
                                    "answer": answers,
                                    "meta": {}
                                }

                            else:
                                yield count, {
                                    "id": each_qa["id"],
                                    "context": each_data["context"],
                                    "question": each_qa["question"],
                                    "answer": answers,
                                }
                            count += 1
        else:
            raise ValueError(f"Invalid config: {self.config.name}")



from pathlib import Path
from typing import Dict, List, Tuple

import datasets
import pandas as pd

from seacrowd.utils import schemas
from seacrowd.utils.configs import SEACrowdConfig
from seacrowd.utils.constants import Licenses, Tasks

_CITATION = """\
@inproceedings{hernandez2021bert,
  title={A bert-based hate speech classifier from transcribed online short-form videos},
  author={Hernandez Urbano Jr, Rommel and Uy Ajero, Jeffrey and Legaspi Angeles, Angelic and Hacar Quintos, Maria Nikki and Regalado Imperial, Joseph Marvin and Llabanes Rodriguez, Ramon},
  booktitle={2021 5th International Conference on E-Society, E-Education and E-Technology},
  year={2021}
}
"""

_LOCAL = False
_LANGUAGES = ["tgl", "eng"]
_DATASETNAME = "filipino_hatespeech_tiktok"

_DESCRIPTION = """\
The dataset contains annotated hate speech from transcribed Tiktok videos, mostly in Taglish (codemixed Tagalog and Cebuano) collected via an unofficial Tiktok API.
Most of the domain and context of the videos are related to politics and general elections in the Philippines. Labeling: 0 - no hate speech, 1 - recognized hate speech
"""

_HOMEPAGE = "https://github.com/imperialite/filipino-tiktok-hatespeech"
_LICENSE = Licenses.CC_BY_SA_4_0.value
_SUPPORTED_TASKS = [Tasks.SENTIMENT_ANALYSIS]
_SOURCE_VERSION = "1.0.0"
_SEACROWD_VERSION = "1.0.0"

_URL = "https://raw.githubusercontent.com/imperialite/filipino-tiktok-hatespeech/main/data"


class FilipinoHateSpeechTikTokDataset(datasets.GeneratorBasedBuilder):
    SOURCE_VERSION = datasets.Version(_SOURCE_VERSION)
    SEACROWD_VERSION = datasets.Version(_SEACROWD_VERSION)

    BUILDER_CONFIGS = [
        SEACrowdConfig(
            name=f"{_DATASETNAME}_source",
            version=SOURCE_VERSION,
            description="Filipino TikTok Hatespeech source schema",
            schema="source",
            subset_id="filipino_hatespeech_tiktok",
        ),
        SEACrowdConfig(
            name=f"{_DATASETNAME}_seacrowd_text",
            version=SEACROWD_VERSION,
            description="Filipino TikTok Hatespeech Seacrowd schema",
            schema="seacrowd_text",
            subset_id="filipino_hatespeech_tiktok",
        ),
    ]

    DEFAULT_CONFIG_NAME = f"{_DATASETNAME}_source"

    def _info(self) -> datasets.DatasetInfo:
        if self.config.schema == "source":
            features = datasets.Features({"text": datasets.Value("string"), "label": datasets.Value("string")})
        elif self.config.schema == "seacrowd_text":
            features = schemas.text.features(label_names=["0", "1"])

        return datasets.DatasetInfo(
            description=_DESCRIPTION,
            features=features,
            homepage=_HOMEPAGE,
            license=_LICENSE,
            citation=_CITATION,
        )

    def _split_generators(self, dl_manager: datasets.DownloadManager) -> List[datasets.SplitGenerator]:
        base_dir = _URL
        data_files = {
            "train": Path(dl_manager.download_and_extract(base_dir + "/train.csv")),
            "test": Path(dl_manager.download_and_extract(base_dir + "/test.csv")),
            "validation": Path(dl_manager.download_and_extract(base_dir + "/valid.csv")),
        }

        return [
            datasets.SplitGenerator(
                name=datasets.Split.TRAIN,
                gen_kwargs={
                    "filepath": data_files["train"],
                    "split": "train",
                },
            ),
            datasets.SplitGenerator(
                name=datasets.Split.TEST,
                gen_kwargs={
                    "filepath": data_files["test"],
                    "split": "test",
                },
            ),
            datasets.SplitGenerator(
                name=datasets.Split.VALIDATION,
                gen_kwargs={
                    "filepath": data_files["validation"],
                    "split": "validation",
                },
            ),
        ]

    def _generate_examples(self, filepath: Path, split: str) -> Tuple[int, Dict]:
        df = pd.read_csv(filepath).reset_index()
        id = 0
        if self.config.schema == "source":
            for row in df.itertuples():
                ex = {"text": row.text, "label": str(row.label)}
                yield id, ex
                id += 1

        elif self.config.schema == "seacrowd_text":
            for row in df.itertuples():
                # Skip NA labels
                if pd.isna(row.label):
                    continue
                ex = {"id": id, "text": row.text, "label": str(int(row.label))}
                yield id, ex
                id += 1
        else:
            raise ValueError(f"Invalid config: {self.config.name}")



# coding=utf-8


from pathlib import Path
from typing import Dict, List, Tuple

import datasets

from seacrowd.utils import schemas
from seacrowd.utils.configs import SEACrowdConfig
from seacrowd.utils.constants import Licenses, Tasks

_CITATION = """\
@inproceedings{kratochvil-morgado-da-costa-2022-abui,
title = "{A}bui {W}ordnet: Using a Toolbox Dictionary to develop a wordnet for a low-resource language",
author = "Kratochvil, Frantisek  and
  Morgado da Costa, Lu{\'}s",
editor = "Serikov, Oleg  and
  Voloshina, Ekaterina  and
  Postnikova, Anna  and
  Klyachko, Elena  and
  Neminova, Ekaterina  and
  Vylomova, Ekaterina  and
  Shavrina, Tatiana  and
  Ferrand, Eric Le  and
  Malykh, Valentin  and
  Tyers, Francis  and
  Arkhangelskiy, Timofey  and
  Mikhailov, Vladislav  and
  Fenogenova, Alena",
booktitle = "Proceedings of the first workshop on NLP applications to field linguistics",
month = oct,
year = "2022",
address = "Gyeongju, Republic of Korea",
publisher = "International Conference on Computational Linguistics",
url = "https://aclanthology.org/2022.fieldmatters-1.7",
pages = "54--63",
abstract = "This paper describes a procedure to link a Toolbox dictionary of a low-resource language to correct
synsets, generating a new wordnet. We introduce a bootstrapping technique utilising the information in the gloss
fields (English, national, and regional) to generate sense candidates using a naive algorithm based on
multilingual sense intersection. We show that this technique is quite effective when glosses are available in
more than one language. Our technique complements the previous work by Rosman et al. (2014) which linked the
SIL Semantic Domains to wordnet senses. Through this work we have created a small, fully hand-checked wordnet
for Abui, containing over 1,400 concepts and 3,600 senses.",
}
"""
_DATASETNAME = "abui_wordnet"
_DESCRIPTION = """\
A small fully hand-checked wordnet for Abui, containing over 1,400 concepts and 3,600 senses, is created. A
bootstrapping technique is introduced to utilise the information in the gloss fields (English, national, and regional)
to generate sense candidates using a naive algorithm based on multilingual sense intersection.
"""

_HOMEPAGE = "https://github.com/fanacek/abuiwn"
_LANGUAGES = ["abz"]
_LICENSE = Licenses.CC_BY_4_0.value
_LOCAL = False
_URLS = {
    _DATASETNAME: "https://raw.githubusercontent.com/fanacek/abuiwn/main/abwn_lmf.tsv",
}

_SUPPORTED_TASKS = [Tasks.WORD_ANALOGY]

_SOURCE_VERSION = "1.0.0"
_SEACROWD_VERSION = "1.0.0"


class AbuiwordnetDataset(datasets.GeneratorBasedBuilder):

    SOURCE_VERSION = datasets.Version(_SOURCE_VERSION)
    SEACROWD_VERSION = datasets.Version(_SEACROWD_VERSION)

    BUILDER_CONFIGS = [
        SEACrowdConfig(
            name=f"{_DATASETNAME}_source",
            version=SOURCE_VERSION,
            description=_DESCRIPTION,
            schema="source",
            subset_id="abui_wordnet",
        ),
        # SEACrowdConfig(
        #     name="abui_wordnet_seacrowd_ww",
        #     version=SEACROWD_VERSION,
        #     description="abuiw SEACrowd schema",
        #     schema="seacrowd_a",
        #     subset_id="abui_wordnet",
        # ),
    ]

    DEFAULT_CONFIG_NAME = f"{_DATASETNAME}_source"

    def _info(self) -> datasets.DatasetInfo:
        features = None
        if self.config.schema == "source":
            features = datasets.Features(
                {
                    "sense": datasets.Value("string"),
                    "pos": datasets.Value("string"),
                    "lang": datasets.Value("string"),
                    "lemma": datasets.Value("string"),
                    "form": datasets.Value("string"),
                }
            )
        elif self.config.schema == "seacrowd_pair":
            features = schemas.pairs_features
            raise NotImplementedError()

        return datasets.DatasetInfo(
            description=_DESCRIPTION,
            features=features,
            homepage=_HOMEPAGE,
            license=_LICENSE,
            citation=_CITATION,
        )

    def _split_generators(self, dl_manager: datasets.DownloadManager) -> List[datasets.SplitGenerator]:
        urls = _URLS[_DATASETNAME]
        data_dir = dl_manager.download_and_extract(urls)
        return [
            datasets.SplitGenerator(
                name="senses",
                gen_kwargs={
                    "filepath": data_dir,
                },
            ),
        ]

    def _generate_examples(self, filepath: Path) -> Tuple[int, Dict]:
        with open(filepath, "r") as filein:
            data_instances = [inst.strip("\n").split("\t") for inst in filein.readlines()]
        if self.config.schema == "source":
            for idx, example in enumerate(data_instances):
                sense = example[0]
                pos = example[0][-1]
                lang = example[1]
                lemma = example[2]
                form = "" if len(example) == 3 else example[3]
                yield idx, {
                    "sense": sense,
                    "pos": pos,
                    "lang": lang,
                    "lemma": lemma,
                    "form": form,
                }
        # elif self.config.schema == "seacrowd_pair":
        #



from pathlib import Path
from typing import Dict, List, Tuple

import datasets
import pandas as pd

from seacrowd.utils import schemas
from seacrowd.utils.configs import SEACrowdConfig
from seacrowd.utils.constants import (DEFAULT_SEACROWD_VIEW_NAME,
                                       DEFAULT_SOURCE_VIEW_NAME, Tasks)

_DATASETNAME = "indo_puisi"
_SOURCE_VIEW_NAME = DEFAULT_SOURCE_VIEW_NAME
_UNIFIED_VIEW_NAME = DEFAULT_SEACROWD_VIEW_NAME

_CITATION = """
"""

_LANGUAGES = ["ind"]  # We follow ISO639-3 language code (https://iso639-3.sil.org/code_tables/639/data)
_LOCAL = False

_DESCRIPTION = """\
Puisi is an Indonesian poetic form. The dataset was collected by scraping various websites. It contains 7223 Indonesian puisi along with the title and author.
"""

_HOMEPAGE = "https://github.com/ilhamfp/puisi-pantun-generator"

_LICENSE = "Creative Commons Attribution Share-Alike 4.0 International"

_SUPPORTED_TASKS = [Tasks.SELF_SUPERVISED_PRETRAINING]

_SOURCE_VERSION = "1.0.0"

_SEACROWD_VERSION = "1.0.0"

_URLS = {
    "train": "https://raw.githubusercontent.com/ilhamfp/puisi-pantun-generator/main/data/puisi.csv",
}


class IndoPuisi(datasets.GeneratorBasedBuilder):
    """IndoPuisi contains 7223 Indonesian puisi along with the title and author."""

    BUILDER_CONFIGS = (
        SEACrowdConfig(
            name="indo_puisi_source",
            version=_SOURCE_VERSION,
            description="Indo puisi source schema",
            schema="source",
            subset_id="indo_puisi",
        ),
        SEACrowdConfig(
            name="indo_puisi_seacrowd_ssp",
            version=_SEACROWD_VERSION,
            description="Indo puisi Nusantara schema",
            schema="seacrowd_ssp",
            subset_id="indo_puisi",
        ),
    )

    DEFAULT_CONFIG_NAME = "indo_puisi_source"

    def _info(self) -> datasets.DatasetInfo:
        if self.config.schema == "source":
            features = datasets.Features(
                {
                    "id": datasets.Value("string"),
                    "puisi": datasets.Value("string"),
                    "title": datasets.Value("string"),
                    "author": datasets.Value("string"),
                    "puisi_with_header": datasets.Value("string"),
                }
            )
        elif self.config.schema == "seacrowd_ssp":
            features = schemas.self_supervised_pretraining.features
        else:
            raise ValueError(f"Invalid config schema: {self.config.schema}")

        return datasets.DatasetInfo(
            description=_DESCRIPTION,
            features=features,
            homepage=_HOMEPAGE,
            license=_LICENSE,
            citation=_CITATION,
        )

    def _split_generators(self, dl_manager: datasets.DownloadManager) -> List[datasets.SplitGenerator]:
        """Returns SplitGenerators."""
        train_csv_path = Path(dl_manager.download(_URLS["train"]))

        return [
            datasets.SplitGenerator(
                name=datasets.Split.TRAIN,
                gen_kwargs={"filepath": train_csv_path},
            ),
        ]

    def _generate_examples(self, filepath: Path) -> Tuple[int, Dict]:
        if self.config.schema != "source" and self.config.schema != "seacrowd_ssp":
            raise ValueError(f"Invalid config schema: {self.config.schema}")

        df = pd.read_csv(filepath).reset_index()
        if self.config.name == "indo_puisi_source":
            for row in df.itertuples():
                ex = {
                    "id": str(row.index),
                    "puisi": str(row.puisi).rstrip(),
                    "title": row.title,
                    "author": row.author,
                    "puisi_with_header": str(row.puisi_with_header).rstrip(),
                }
                yield row.index, ex

        elif self.config.name == "indo_puisi_seacrowd_ssp":
            for row in df.itertuples():
                ex = {"id": str(row.index), "text": str(row.puisi).rstrip()}
                yield row.index, ex



# coding=utf-8
# Copyright 2022 The HuggingFace Datasets Authors and the current dataset script contributor.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
This dataset is collected from electronic newspapers published on the web and provided by VLSP organization.\
It consists of approximately 15k sentences, each of which contain NE information in the IOB annotation format\
"""
from pathlib import Path
from typing import Dict, List, Tuple

import datasets
import pandas as pd

from seacrowd.utils import schemas
from seacrowd.utils.configs import SEACrowdConfig
from seacrowd.utils.constants import Licenses, Tasks

_CITATION = """\
@article{nguyen-et-al-2019-vlsp-ner,
author = {Nguyen, Huyen and Ngo, Quyen and Vu, Luong and Mai, Vu and Nguyen, Hien},
year = {2019},
month = {01},
pages = {283-294},
title = {VLSP Shared Task: Named Entity Recognition},
volume = {34},
journal = {Journal of Computer Science and Cybernetics},
doi = {10.15625/1813-9663/34/4/13161}
}
"""

_DATASETNAME = "vlsp2016_ner"

_DESCRIPTION = """\
This dataset is collected from electronic newspapers published on the web and provided by VLSP organization. \
It consists of approximately 15k sentences, each of which contain NE information in the IOB annotation format
"""

_HOMEPAGE = "https://huggingface.co/datasets/datnth1709/VLSP2016-NER-data"

_LANGUAGES = ["vie"]  # We follow ISO639-3 language code (https://iso639-3.sil.org/code_tables/639/data)

_LICENSE = Licenses.CC_BY_NC_4_0.value

_LOCAL = False

_URLS = {
    _DATASETNAME: {
        "train": "https://huggingface.co/datasets/datnth1709/VLSP2016-NER-data/resolve/main/data/train-00000-of-00001-b0417886a268b83a.parquet?download=true",
        "test": "https://huggingface.co/datasets/datnth1709/VLSP2016-NER-data/resolve/main/data/valid-00000-of-00001-846411c236133ba3.parquet?download=true",
    },
}

_SUPPORTED_TASKS = [Tasks.NAMED_ENTITY_RECOGNITION]  # example: [Tasks.TRANSLATION, Tasks.NAMED_ENTITY_RECOGNITION, Tasks.RELATION_EXTRACTION]

_SOURCE_VERSION = "1.0.0"

_SEACROWD_VERSION = "1.0.0"


class Visp2016NER(datasets.GeneratorBasedBuilder):
    """This dataset is collected from electronic newspapers published on the web and provided by VLSP organization.
    It consists of approximately 15k sentences, each of which contain NE information in the IOB annotation format"""

    SOURCE_VERSION = datasets.Version(_SOURCE_VERSION)
    SEACROWD_VERSION = datasets.Version(_SEACROWD_VERSION)

    BUILDER_CONFIGS = [
        SEACrowdConfig(
            name="vlsp2016_ner_source",
            version=SOURCE_VERSION,
            description="vlsp2016_ner source schema",
            schema="source",
            subset_id="vlsp2016_ner",
        ),
        SEACrowdConfig(
            name="vlsp2016_ner_seacrowd_seq_label",
            version=SEACROWD_VERSION,
            description="vlsp2016_ner SEACrowd schema",
            schema="seacrowd_seq_label",
            subset_id="vlsp2016_ner",
        ),
    ]

    DEFAULT_CONFIG_NAME = "vlsp2016_ner_source"

    def _info(self) -> datasets.DatasetInfo:
        if self.config.schema == "source":
            features = datasets.Features(
                {
                    "tokens": datasets.Sequence(datasets.Value("string")),
                    "ner_tags": datasets.Sequence(datasets.Value("int64")),
                }
            )
        elif self.config.schema == "seacrowd_seq_label":
            features = schemas.seq_label.features([x for x in range(9)])

        return datasets.DatasetInfo(
            description=_DESCRIPTION,
            features=features,
            homepage=_HOMEPAGE,
            license=_LICENSE,
            citation=_CITATION,
        )

    def _split_generators(self, dl_manager: datasets.DownloadManager) -> List[datasets.SplitGenerator]:
        """Returns SplitGenerators."""
        train_url = _URLS[_DATASETNAME]["train"]
        train_path = dl_manager.download_and_extract(train_url)

        test_url = _URLS[_DATASETNAME]["test"]
        test_path = dl_manager.download_and_extract(test_url)

        return [
            datasets.SplitGenerator(
                name=datasets.Split.TRAIN,
                gen_kwargs={
                    "filepath": train_path,
                    "split": "train",
                },
            ),
            datasets.SplitGenerator(
                name=datasets.Split.TEST,
                gen_kwargs={
                    "filepath": test_path,
                    "split": "test",
                },
            ),
        ]

    def _generate_examples(self, filepath: Path, split: str) -> Tuple[int, Dict]:
        df = pd.read_parquet(filepath)
        if self.config.schema == "source":
            for i in range(len(df)):
                row = df.iloc[i]
                yield (
                    i,
                    {
                        "tokens": row["tokens"],
                        "ner_tags": row["ner_tags"],
                    },
                )
        elif self.config.schema == "seacrowd_seq_label":
            for i in range(len(df)):
                row = df.iloc[i]
                yield (
                    i,
                    {
                        "id": i,
                        "tokens": row["tokens"],
                        "labels": row["ner_tags"],
                    },
                )



# coding=utf-8
# Copyright 2022 The HuggingFace Datasets Authors and the current dataset script contributor.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from pathlib import Path
from typing import Dict, List, Tuple

import datasets
import pandas as pd

from seacrowd.utils import schemas
from seacrowd.utils.configs import SEACrowdConfig
from seacrowd.utils.constants import Licenses, Tasks

_CITATION = """\
@InProceedings{10.1007/978-981-16-8515-6_44,
author="Juan, Sarah Samson
and Saee, Suhaila
and Mohamad, Fitri",
editor="Alfred, Rayner
and Lim, Yuto",
title="Social Versus Physical Distancing: Analysis of Public Health Messages at the Start of COVID-19 Outbreak in Malaysia Using Natural Language Processing",
booktitle="Proceedings of the 8th International Conference on Computational Science and Technology",
year="2022",
publisher="Springer Singapore",
address="Singapore",
pages="577--589",
abstract="The study presents an attempt to analyse how social media netizens in Malaysia responded to the calls for ``Social Distancing'' and ``Physical Distancing'' as the newly recommended social norm was introduced to the world
as a response to the COVID-19 global pandemic. The pandemic drove a sharp increase in social media platforms' use as a public health communication platform since the first wave of the COVID-19 outbreak in Malaysia in April 2020.
We analysed thousands of tweets posted by Malaysians daily between January 2020 and August 2021 to determine public perceptions and interactions patterns. The analysis focused on positive and negative reactions
and the interchanges of uses of the recommended terminologies ``social distancing'' and ``physical distancing''. Using linguistic analysis and natural language processing,
findings dominantly indicate influences from the multilingual and multicultural values held by Malaysian netizens, as they embrace the concept of distancing as a measure of global public health safety.",
isbn="978-981-16-8515-6"
}
"""

_DATASETNAME = "malaysia_tweets"
_DESCRIPTION = """\
This tweet data was extracted from tweets in Malaysia based on keywords
"social distancing" and "physical distancing". We conducted
sentiment analysis to understand public opinions on health messages
during the COVID-19 pandemic. Tweets from January 2020 to July 2021
were extracted using Python module snscrape and sentiments were obtained
automatically using Polyglot and MALAYA NLP tools due to multilingual data.
"""

_HOMEPAGE = "https://github.com/sarahjuan/malaysia-tweets-with-sentiment-labels"

_LANGUAGES = ["zlm,", "eng"]  # We follow ISO639-3 language code (https://iso639-3.sil.org/code_tables/639/data)

_LICENSE = Licenses.UNKNOWN.value  # example: Licenses.MIT.value, Licenses.CC_BY_NC_SA_4_0.value, Licenses.UNLICENSE.value, Licenses.UNKNOWN.value

_LOCAL = False

_URLS = {
    _DATASETNAME: "https://raw.githubusercontent.com/sarahjuan/malaysia-tweets-with-sentiment-labels/main/data/cleaned_tweets_sentiments.csv",
}

_SUPPORTED_TASKS = [Tasks.SENTIMENT_ANALYSIS]  # example: [Tasks.TRANSLATION, Tasks.NAMED_ENTITY_RECOGNITION, Tasks.RELATION_EXTRACTION]

_SOURCE_VERSION = "1.0.0"

_SEACROWD_VERSION = "1.0.0"


class MalaysiaTweetsDataset(datasets.GeneratorBasedBuilder):
    """This tweet data was extracted from tweets in Malaysia based on keywords
    "social distancing" and "physical distancing" from January 2020 to July 2021."""

    SOURCE_VERSION = datasets.Version(_SOURCE_VERSION)
    SEACROWD_VERSION = datasets.Version(_SEACROWD_VERSION)

    SEACROWD_SCHEMA_NAME = "text"

    BUILDER_CONFIGS = [
        SEACrowdConfig(
            name=f"{_DATASETNAME}_source",
            version=SOURCE_VERSION,
            description=f"{_DATASETNAME} source schema",
            schema="source",
            subset_id=f"{_DATASETNAME}",
        ),
        SEACrowdConfig(
            name=f"{_DATASETNAME}_seacrowd_{SEACROWD_SCHEMA_NAME}",
            version=SEACROWD_VERSION,
            description=f"{_DATASETNAME} SEACrowd schema",
            schema=f"seacrowd_{SEACROWD_SCHEMA_NAME}",
            subset_id=f"{_DATASETNAME}",
        ),
    ]

    DEFAULT_CONFIG_NAME = f"{_DATASETNAME}_source"
    SENTIMENT_LABEL_CLASSES = ["POSITIVE", "NEGATIVE", "NEUTRAL"]

    def _info(self) -> datasets.DatasetInfo:
        if self.config.schema == "source":
            features = datasets.Features(
                {
                    "Tweet": datasets.Value("string"),
                    "Sentiment": datasets.ClassLabel(names=self.SENTIMENT_LABEL_CLASSES),
                }
            )

        elif self.config.schema == f"seacrowd_{self.SEACROWD_SCHEMA_NAME}":
            features = schemas.text_features(self.SENTIMENT_LABEL_CLASSES)

        return datasets.DatasetInfo(
            description=_DESCRIPTION,
            features=features,
            homepage=_HOMEPAGE,
            license=_LICENSE,
            citation=_CITATION,
        )

    def _split_generators(self, dl_manager: datasets.DownloadManager) -> List[datasets.SplitGenerator]:
        """Returns SplitGenerators."""

        urls = _URLS[_DATASETNAME]
        data_dir = dl_manager.download_and_extract(urls)

        return [
            datasets.SplitGenerator(
                name=datasets.Split.TRAIN,
                gen_kwargs={
                    "filepath": data_dir,
                    "split": "train",
                },
            )
        ]

    def _generate_examples(self, filepath: Path, split: str) -> Tuple[int, Dict]:
        """Yields examples as (key, example) tuples."""

        df = pd.read_csv(filepath, encoding="utf-8")
        if self.config.schema == "source":
            for idx, row in df.iterrows():
                yield idx, dict(row)

        elif self.config.schema == f"seacrowd_{self.SEACROWD_SCHEMA_NAME}":
            for idx, row in df.iterrows():
                yield idx, {"id": idx, "text": row["Tweet"], "label": row["Sentiment"]}



"""
SpeechText Schema
"""
import datasets

features = datasets.Features(
    {
        "id": datasets.Value("string"),
        "path": datasets.Value("string"),
        "audio": datasets.Audio(sampling_rate=16_000),
        "text": datasets.Value("string"),
        "speaker_id": datasets.Value("string"),
        "metadata": {
            "speaker_age": datasets.Value("int64"),
            "speaker_gender": datasets.Value("string"),
        }
    }
)
